@@ -1,21 +1,23 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* eab-editor.c
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
- * Author: Chris Toshok <toshok@ximian.com>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+/*
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ *
+ *
+ * Authors:
+ *		Chris Toshok <toshok@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * You should have received a copy of the GNU General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -27,7 +29,7 @@
 
 #include "eab-editor.h"
 #include "addressbook/gui/widgets/eab-gui-util.h"
-#include "e-contact-editor-marshal.h"
+#include "e-util/e-util.h"
 
 static void eab_editor_default_show  (EABEditor *editor);
 static void eab_editor_default_raise (EABEditor *editor);
@@ -140,7 +142,7 @@ eab_editor_class_init (EABEditorClass *klass)
 			      G_SIGNAL_RUN_FIRST,
 			      G_STRUCT_OFFSET (EABEditorClass, contact_added),
 			      NULL, NULL,
-			      e_contact_editor_marshal_NONE__INT_OBJECT,
+			      e_marshal_NONE__INT_OBJECT,
 			      G_TYPE_NONE, 2,
 			      G_TYPE_INT, G_TYPE_OBJECT);
 
@@ -150,7 +152,7 @@ eab_editor_class_init (EABEditorClass *klass)
 			      G_SIGNAL_RUN_FIRST,
 			      G_STRUCT_OFFSET (EABEditorClass, contact_modified),
 			      NULL, NULL,
-			      e_contact_editor_marshal_NONE__INT_OBJECT,
+			      e_marshal_NONE__INT_OBJECT,
 			      G_TYPE_NONE, 2,
 			      G_TYPE_INT, G_TYPE_OBJECT);
 
@@ -160,7 +162,7 @@ eab_editor_class_init (EABEditorClass *klass)
 			      G_SIGNAL_RUN_FIRST,
 			      G_STRUCT_OFFSET (EABEditorClass, contact_deleted),
 			      NULL, NULL,
-			      e_contact_editor_marshal_NONE__INT_OBJECT,
+			      e_marshal_NONE__INT_OBJECT,
 			      G_TYPE_NONE, 2,
 			      G_TYPE_INT, G_TYPE_OBJECT);
 
