@@ -30,7 +30,6 @@
 #define G_LOG_DOMAIN "etodoconduit"
 
 #include <glib/gi18n.h>
-#include <libgnome/gnome-config.h>
 #include <libecal/e-cal-types.h>
 #include <libecal/e-cal.h>
 #include <libecal/e-cal-time-util.h>
@@ -122,8 +121,7 @@ todoconduit_load_configuration (guint32 pilot_id)
 	gchar prefix[256];
 
 
-	g_snprintf (prefix, 255, "/gnome-pilot.d/e-todo-conduit/Pilot_%u/",
-		    pilot_id);
+	g_snprintf (prefix, 255, "e-todo-conduit/Pilot_%u", pilot_id);
 
 	c = g_new0 (EToDoConduitCfg,1);
 	g_assert (c != NULL);
@@ -140,8 +138,6 @@ todoconduit_load_configuration (guint32 pilot_id)
 	g_object_unref (management);
 
 	/* Custom settings */
-	gnome_config_push_prefix (prefix);
-
 	if (!e_cal_get_sources (&c->source_list, E_CAL_SOURCE_TYPE_TODO, NULL))
 		c->source_list = NULL;
 	if (c->source_list) {
@@ -156,11 +152,9 @@ todoconduit_load_configuration (guint32 pilot_id)
 		}
 	}
 
-	c->secret = gnome_config_get_bool ("secret=FALSE");
-	c->priority = gnome_config_get_int ("priority=3");
-	c->last_uri = gnome_config_get_string ("last_uri");
-
-	gnome_config_pop_prefix ();
+	c->secret = e_pilot_setup_get_bool (prefix, "secret", FALSE);
+	c->priority = e_pilot_setup_get_int (prefix, "priority", 3);
+	c->last_uri = e_pilot_setup_get_string (prefix, "last_uri", NULL);
 
 	return c;
 }
@@ -170,18 +164,12 @@ todoconduit_save_configuration (EToDoConduitCfg *c)
 {
 	gchar prefix[256];
 
-	g_snprintf (prefix, 255, "/gnome-pilot.d/e-todo-conduit/Pilot_%u/",
-		    c->pilot_id);
+	g_snprintf (prefix, 255, "e-todo-conduit/Pilot_%u", c->pilot_id);
 
-	gnome_config_push_prefix (prefix);
 	e_pilot_set_sync_source (c->source_list, c->source);
-	gnome_config_set_bool ("secret", c->secret);
-	gnome_config_set_int ("priority", c->priority);
-	gnome_config_set_string ("last_uri", c->last_uri);
-	gnome_config_pop_prefix ();
-
-	gnome_config_sync ();
-	gnome_config_drop_all ();
+	e_pilot_setup_set_bool (prefix, "secret", c->secret);
+	e_pilot_setup_set_int (prefix, "priority", c->priority);
+	e_pilot_setup_set_string (prefix, "last_uri", c->last_uri ? c->last_uri : "");
 }
 
 static EToDoConduitCfg*
@@ -764,12 +752,13 @@ local_record_from_comp (EToDoLocalRecord *local, ECalComponent *comp, EToDoCondu
 			local->todo->priority = 4;
 		else
 			local->todo->priority = 5;
-
-		e_cal_component_free_priority (priority);
 	} else {
 		local->todo->priority = ctxt->cfg->priority;
 	}
 
+	if (priority)
+		e_cal_component_free_priority (priority);
+
 	e_cal_component_get_classification (comp, &classif);
 
 	if (classif == E_CAL_COMPONENT_CLASS_PRIVATE)
@@ -1024,7 +1013,7 @@ pre_sync (GnomePilotConduit *conduit,
 	/* Get the default component */
 	if (!e_cal_get_default_object (ctxt->client, &icalcomp, NULL))
 		return -1;
-	LOG (g_message ( "  Got default component: %p", icalcomp));
+	LOG (g_message ("  Got default component: %p", (gpointer) icalcomp));
 
 	ctxt->default_comp = e_cal_component_new ();
 	if (!e_cal_component_set_icalcomponent (ctxt->default_comp, icalcomp)) {
