@@ -34,7 +34,6 @@
 #include <bonobo/bonobo-main.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
-#include <libgnome/gnome-exec.h>
 #include <libgnome/gnome-sound.h>
 
 #include <libecal/e-cal-time-util.h>
@@ -55,10 +54,6 @@
 #include "e-util/e-popup.h"
 #include "e-util/e-error.h"
 
-#if !GTK_CHECK_VERSION(2,16,0)
-#define gtk_status_icon_set_tooltip_text gtk_status_icon_set_tooltip
-#endif
-
 #define d(x)
 
 /* The dialog with alarm nofications */
@@ -1545,7 +1540,7 @@ display_notification (time_t trigger, CompQueuedAlarms *cqa,
 	g_signal_connect (G_OBJECT (tray_data->query), "objects_removed",
 			  G_CALLBACK (on_dialog_objs_removed_cb), tray_data);
 
-	// FIXME: We should remove this check
+	/* FIXME: We should remove this check */
 	if (!config_data_get_notify_with_tray ()) {
 		tray_blink_id = -1;
 		open_alarm_dialog (tray_data);
@@ -1763,7 +1758,7 @@ procedure_notification (time_t trigger, CompQueuedAlarms *cqa, gpointer alarm_id
 	icalattach *attach;
 	const char *url;
 	char *cmd;
-	int result;
+	gboolean result = TRUE;
 
 	d(printf("%s:%d (procedure_notification)\n",__FILE__, __LINE__));
 
@@ -1797,9 +1792,8 @@ procedure_notification (time_t trigger, CompQueuedAlarms *cqa, gpointer alarm_id
 	else
 		cmd = (char *) url;
 
-	result = 0;
 	if (procedure_notification_dialog (cmd, url))
-		result = gnome_execute_shell (NULL, cmd);
+		result = g_spawn_command_line_async (cmd, NULL);
 
 	if (cmd != (char *) url)
 		g_free (cmd);
@@ -1807,7 +1801,7 @@ procedure_notification (time_t trigger, CompQueuedAlarms *cqa, gpointer alarm_id
 	icalattach_unref (attach);
 
 	/* Fall back to display notification if we got an error */
-	if (result < 0)
+	if (result == FALSE)
 		goto fallback;
 
 	return;
@@ -1817,8 +1811,6 @@ procedure_notification (time_t trigger, CompQueuedAlarms *cqa, gpointer alarm_id
 	display_notification (trigger, cqa, alarm_id, FALSE);
 }
 
-
-
 static gboolean
 check_midnight_refresh (gpointer user_data)
 {
@@ -1868,7 +1860,7 @@ alarm_queue_init (gpointer data)
 	}
 
 	/* install timeout handler (every 30 mins) for not missing the midnight refresh */
-	g_timeout_add (1800000, (GSourceFunc) check_midnight_refresh, NULL);
+	g_timeout_add_seconds (1800, (GSourceFunc) check_midnight_refresh, NULL);
 
 #ifdef HAVE_LIBNOTIFY
 	notify_init("Evolution Alarms");
