@@ -43,9 +43,10 @@ struct _CalendarPrefsDialog {
 	GConfClient *gconf;
 
 	/* General tab */
+	GtkWidget *use_system_tz_check;
+	GtkWidget *system_tz_label;
 	GtkWidget *timezone;
 	GtkWidget *day_second_zone;
-	GtkWidget *daylight_saving;
 	GtkWidget *working_days[7];
 	GtkWidget *week_start_day;
 	GtkWidget *start_of_day;
@@ -66,6 +67,7 @@ struct _CalendarPrefsDialog {
 	GtkWidget *compress_weekend;
 	GtkWidget *dnav_show_week_no;
 	GtkWidget *dview_show_week_no;
+	GtkWidget *month_scroll_by_week;
 	GtkWidget *tasks_due_today_color;
 	GtkWidget *tasks_overdue_color;
 	GtkWidget *tasks_hide_completed;
