@@ -182,6 +182,14 @@ enum {
 
 static guint comp_editor_signals[LAST_SIGNAL] = { 0 };
 
+static void
+attachment_store_changed_cb (CompEditor *editor)
+{
+	/* Mark the editor as changed so it prompts about unsaved
+           changes on close */
+	comp_editor_set_changed (editor, TRUE);
+}
+
 static GSList *
 get_attachment_list (CompEditor *editor)
 {
@@ -189,7 +197,7 @@ get_attachment_list (CompEditor *editor)
 	EAttachmentView *view;
 	GtkTreeModel *model;
 	GtkTreeIter iter;
-	GSList *parts = NULL, *list = NULL;
+	GSList *list = NULL;
 	const char *comp_uid = NULL;
 	const char *local_store = e_cal_get_local_attachment_store (editor->priv->client);
 	gboolean valid;
@@ -274,8 +282,6 @@ get_attachment_list (CompEditor *editor)
 		g_free (filename);
 	}
 
-	if (parts)
-		g_slist_free (parts);
 	return list;
 }
 
@@ -1513,6 +1519,7 @@ comp_editor_init (CompEditor *editor)
 {
 	CompEditorPrivate *priv;
 	EAttachmentView *view;
+	EAttachmentStore *store;
 	GdkDragAction drag_actions;
 	GtkTargetList *target_list;
 	GtkTargetEntry *targets;
@@ -1646,6 +1653,18 @@ comp_editor_init (CompEditor *editor)
 
 	gtk_window_set_type_hint (
 		GTK_WINDOW (editor), GDK_WINDOW_TYPE_HINT_NORMAL);
+
+	/* Listen for attachment store changes. */
+
+	store = e_attachment_view_get_store (view);
+
+	g_signal_connect_swapped (
+		store, "row-deleted",
+		G_CALLBACK (attachment_store_changed_cb), editor);
+
+	g_signal_connect_swapped (
+		store, "row-inserted",
+		G_CALLBACK (attachment_store_changed_cb), editor);
 }
 
 static gboolean
@@ -1698,14 +1717,6 @@ prompt_and_save_changes (CompEditor *editor, gboolean send)
 	}
 }
 
-static void
-attachment_store_changed_cb (CompEditor *editor)
-{
-	/* Mark the editor as changed so it prompts about unsaved
-           changes on close */
-	comp_editor_set_changed (editor, TRUE);
-}
-
 /* Menu callbacks */
 
 static void
@@ -1837,7 +1848,7 @@ comp_editor_set_summary (CompEditor *editor,
 		!editor->priv->warned &&
 		!(editor->priv->flags & COMP_EDITOR_DELEGATE) &&
 		editor->priv->existing_org &&
-		!editor->priv->user_org;
+		!editor->priv->user_org && !(editor->priv->flags & COMP_EDITOR_NEW_ITEM);
 
 	if (show_warning) {
 		e_notice (
@@ -1885,7 +1896,8 @@ comp_editor_set_changed (CompEditor *editor,
 	show_warning =
 		changed && !editor->priv->warned &&
 		!(editor->priv->flags & COMP_EDITOR_DELEGATE) &&
-		editor->priv->existing_org && !editor->priv->user_org;
+		editor->priv->existing_org && !editor->priv->user_org
+		&& !(editor->priv->flags & COMP_EDITOR_NEW_ITEM);
 
 	if (show_warning) {
 		e_notice (
@@ -2690,7 +2702,7 @@ page_dates_changed_cb (CompEditor *editor,
 		if (page != (CompEditorPage *) l->data)
 			comp_editor_page_set_dates (l->data, dates);
 
-	if (!priv->warned && priv->existing_org && !priv->user_org) {
+	if (!priv->warned && priv->existing_org && !priv->user_org && !(editor->priv->flags & COMP_EDITOR_NEW_ITEM)) {
 		e_notice (priv->notebook, GTK_MESSAGE_INFO,
 			  _("Changes made to this item may be discarded if an update arrives"));
 		priv->warned = TRUE;
