@@ -99,7 +99,7 @@ static const gchar *ui =
 "</ui>";
 
 static void event_editor_edit_comp (CompEditor *editor, ECalComponent *comp);
-static gboolean event_editor_send_comp (CompEditor *editor, ECalComponentItipMethod method);
+static gboolean event_editor_send_comp (CompEditor *editor, ECalComponentItipMethod method, gboolean strip_alarms);
 
 G_DEFINE_TYPE (EventEditor, event_editor, TYPE_COMP_EDITOR)
 
@@ -113,7 +113,7 @@ create_schedule_page (CompEditor *editor)
 	priv = EVENT_EDITOR_GET_PRIVATE (editor);
 
 	priv->sched_window = gtk_dialog_new_with_buttons (
-		_("Free/Busy"), GTK_WINDOW (editor), GTK_DIALOG_MODAL,
+		_("Free/Busy"), GTK_WINDOW (editor), GTK_DIALOG_DESTROY_WITH_PARENT,
 		GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE, NULL);
 
 	g_signal_connect (
@@ -168,7 +168,7 @@ action_free_busy_cb (GtkAction *action,
 	if (editor->priv->sched_window == NULL)
 		create_schedule_page (COMP_EDITOR (editor));
 	else
-		gtk_widget_show (editor->priv->sched_window);
+		gtk_window_present (GTK_WINDOW (editor->priv->sched_window));
 }
 
 static void
@@ -463,7 +463,7 @@ static void
 event_editor_init (EventEditor *ee)
 {
 	CompEditor *editor = COMP_EDITOR (ee);
-	GtkUIManager *manager;
+	GtkUIManager *ui_manager;
 	GtkActionGroup *action_group;
 	GtkAction *action;
 	GError *error = NULL;
@@ -486,9 +486,9 @@ event_editor_init (EventEditor *ee)
 		action_group, meeting_entries,
 		G_N_ELEMENTS (meeting_entries), ee);
 
-	manager = comp_editor_get_ui_manager (editor);
-	gtk_ui_manager_add_ui_from_string (manager, ui, -1, &error);
-	e_plugin_ui_register_manager ("event-editor", manager, ee);
+	ui_manager = comp_editor_get_ui_manager (editor);
+	gtk_ui_manager_add_ui_from_string (ui_manager, ui, -1, &error);
+	e_plugin_ui_register_manager ("event-editor", ui_manager, ee);
 
 	if (error != NULL) {
 		g_critical ("%s: %s", G_STRFUNC, error->message);
@@ -512,8 +512,6 @@ event_editor_init (EventEditor *ee)
 	g_signal_connect_swapped (
 		ee->priv->model, "row_deleted",
 		G_CALLBACK (event_editor_model_changed_cb), ee);
-
-	gtk_window_set_default_size (GTK_WINDOW (ee), 300, 225);
 }
 
 static void
@@ -565,6 +563,8 @@ event_editor_edit_comp (CompEditor *editor, ECalComponent *comp)
 		}
 
 		if (!(delegate && e_cal_get_static_capability (client, CAL_STATIC_CAPABILITY_DELEGATE_TO_MANY))) {
+			event_page_remove_all_attendees (priv->event_page);
+
 			for (l = attendees; l != NULL; l = l->next) {
 				ECalComponentAttendee *ca = l->data;
 				EMeetingAttendee *ia;
@@ -614,13 +614,13 @@ event_editor_edit_comp (CompEditor *editor, ECalComponent *comp)
 	}
 	e_cal_component_free_attendee_list (attendees);
 
-	comp_editor_set_needs_send (editor, priv->meeting_shown && (itip_organizer_is_user (comp, client) || itip_sentby_is_user (comp)));
+	comp_editor_set_needs_send (editor, priv->meeting_shown && (itip_organizer_is_user (comp, client) || itip_sentby_is_user (comp, client)));
 
 	priv->updating = FALSE;
 }
 
 static gboolean
-event_editor_send_comp (CompEditor *editor, ECalComponentItipMethod method)
+event_editor_send_comp (CompEditor *editor, ECalComponentItipMethod method, gboolean strip_alarms)
 {
 	EventEditorPrivate *priv;
 	ECalComponent *comp = NULL;
@@ -639,7 +639,7 @@ event_editor_send_comp (CompEditor *editor, ECalComponentItipMethod method)
 
 		client = e_meeting_store_get_e_cal (priv->model);
 		result = itip_send_comp (E_CAL_COMPONENT_METHOD_CANCEL, comp,
-				client, NULL, NULL, NULL);
+				client, NULL, NULL, NULL, strip_alarms);
 		g_object_unref (comp);
 
 		return result;
@@ -647,7 +647,7 @@ event_editor_send_comp (CompEditor *editor, ECalComponentItipMethod method)
 
  parent:
 	if (COMP_EDITOR_CLASS (event_editor_parent_class)->send_comp)
-		return COMP_EDITOR_CLASS (event_editor_parent_class)->send_comp (editor, method);
+		return COMP_EDITOR_CLASS (event_editor_parent_class)->send_comp (editor, method, strip_alarms);
 
 	return FALSE;
 }
