@@ -96,6 +96,21 @@ memo_editor_dispose (GObject *object)
 	G_OBJECT_CLASS (memo_editor_parent_class)->dispose (object);
 }
 
+static void
+memo_editor_constructed (GObject *object)
+{
+	MemoEditorPrivate *priv;
+	CompEditor *editor;
+
+	priv = MEMO_EDITOR_GET_PRIVATE (object);
+	editor = COMP_EDITOR (object);
+
+	priv->memo_page = memo_page_new (editor);
+	comp_editor_append_page (
+		editor, COMP_EDITOR_PAGE (priv->memo_page),
+		_("Memo"), TRUE);
+}
+
 static void
 memo_editor_class_init (MemoEditorClass *class)
 {
@@ -106,6 +121,7 @@ memo_editor_class_init (MemoEditorClass *class)
 
 	object_class = G_OBJECT_CLASS (class);
 	object_class->dispose = memo_editor_dispose;
+	object_class->constructed = memo_editor_constructed;
 
 	/* TODO Add a help section for memos. */
 	editor_class = COMP_EDITOR_CLASS (class);
@@ -118,26 +134,20 @@ static void
 memo_editor_init (MemoEditor *me)
 {
 	CompEditor *editor = COMP_EDITOR (me);
-	GtkUIManager *manager;
+	GtkUIManager *ui_manager;
 	GError *error = NULL;
 
 	me->priv = MEMO_EDITOR_GET_PRIVATE (me);
 	me->priv->updating = FALSE;
 
-	manager = comp_editor_get_ui_manager (editor);
-	gtk_ui_manager_add_ui_from_string (manager, ui, -1, &error);
-	e_plugin_ui_register_manager ("memo-editor", manager, me);
+	ui_manager = comp_editor_get_ui_manager (editor);
+	gtk_ui_manager_add_ui_from_string (ui_manager, ui, -1, &error);
+	e_plugin_ui_register_manager ("memo-editor", ui_manager, me);
 
 	if (error != NULL) {
 		g_critical ("%s: %s", G_STRFUNC, error->message);
 		g_error_free (error);
 	}
-
-	me->priv->memo_page = memo_page_new (editor);
-	comp_editor_append_page (
-		COMP_EDITOR (me),
-		COMP_EDITOR_PAGE (me->priv->memo_page),
-		_("Memo"), TRUE);
 }
 
 /**
