@@ -42,8 +42,6 @@
 #include <table/e-cell-combo.h>
 #include <misc/e-popup-menu.h>
 #include <misc/e-cell-date-edit.h>
-#include <libgnome/gnome-exec.h>
-#include <libgnome/gnome-util.h>
 #include <e-util/e-categories-config.h>
 #include <e-util/e-dialog-utils.h>
 #include <e-util/e-util-private.h>
