@@ -31,10 +31,10 @@
 #include <glib/gstdio.h>
 #include <gdk/gdkkeysyms.h>
 #include <libedataserver/e-time-utils.h>
+#include <e-util/e-util.h>
 #include <e-util/e-error.h>
 #include <e-util/e-dialog-utils.h>
 #include <e-util/e-icon-factory.h>
-#include "e-calendar-marshal.h"
 #include <libecal/e-cal-time-util.h>
 #include <libecal/e-cal-component.h>
 
@@ -78,14 +78,13 @@ struct _ECalendarViewPrivate {
 static void e_calendar_view_get_property (GObject *object, guint property_id, GValue *value, GParamSpec *pspec);
 static void e_calendar_view_set_property (GObject *object, guint property_id, const GValue *value, GParamSpec *pspec);
 static void e_calendar_view_destroy (GtkObject *object);
-static void open_event_with_flags (ECalendarView *cal_view, ECal *client, icalcomponent *icalcomp, guint32 flags);
 
 extern ECompEditorRegistry *comp_editor_registry;
 
 /* Property IDs */
 enum props {
 	PROP_0,
-	PROP_MODEL,
+	PROP_MODEL
 };
 
 /* FIXME Why are we emitting these event signals here? Can't the model just be listened to? */
@@ -204,7 +203,7 @@ e_calendar_view_class_init (ECalendarViewClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (ECalendarViewClass, timezone_changed),
 			      NULL, NULL,
-			      e_calendar_marshal_VOID__POINTER_POINTER,
+			      e_marshal_VOID__POINTER_POINTER,
 			      G_TYPE_NONE, 2, G_TYPE_POINTER, G_TYPE_POINTER);
 
 	e_calendar_view_signals[EVENT_CHANGED] =
@@ -272,7 +271,7 @@ e_calendar_view_add_event (ECalendarView *cal_view, ECal *client, time_t dtstart
 	gint start_offset, end_offset;
 	gboolean all_day_event = FALSE;
 	GnomeCalendarViewType view_type;
-	ECalComponentDateTime dt;
+	GError *error = NULL;
 
 	start_offset = 0;
 	end_offset = 0;
@@ -329,15 +328,16 @@ e_calendar_view_add_event (ECalendarView *cal_view, ECal *client, time_t dtstart
 			new_time.minute = old_dtstart.minute;
 			new_time.second = old_dtstart.second;
 
-			new_dtstart = icaltime_as_timet_with_zone (new_time, default_zone);
+			new_dtstart = icaltime_as_timet_with_zone (new_time, old_dtstart.zone ? old_dtstart.zone : default_zone);
 		}
 		break;
 	default:
 		g_return_if_reached ();
 	}
 
-
-	itime = icaltime_from_timet_with_zone (new_dtstart, FALSE, default_zone);
+	itime = icaltime_from_timet_with_zone (new_dtstart, FALSE, old_dtstart.zone ? old_dtstart.zone : default_zone);
+	/* set the timezone properly */
+	itime.zone = old_dtstart.zone ? old_dtstart.zone : default_zone;
 	if (all_day_event)
 		itime.is_date = TRUE;
 	icalcomponent_set_dtstart (icalcomp, itime);
@@ -356,39 +356,27 @@ e_calendar_view_add_event (ECalendarView *cal_view, ECal *client, time_t dtstart
 	e_cal_component_set_uid (comp, uid);
 	g_free (uid);
 
-	/* set the timezone properly */
-	e_cal_component_get_dtstart (comp, &dt);
-	g_free ((char *) dt.tzid);
-	dt.tzid = icaltimezone_get_tzid (default_zone);
-	e_cal_component_set_dtstart (comp, &dt);
-	dt.tzid = NULL;
-	e_cal_component_free_datetime (&dt);
-
-	e_cal_component_get_dtend (comp, &dt);
-	g_free ((char *) dt.tzid);
-	dt.tzid = icaltimezone_get_tzid (default_zone);
-	e_cal_component_set_dtend (comp, &dt);
-	dt.tzid = NULL;
-	e_cal_component_free_datetime (&dt);
-
 	e_cal_component_commit_sequence (comp);
 
-	/* FIXME Error handling */
 	uid = NULL;
-	if (e_cal_create_object (client, e_cal_component_get_icalcomponent (comp), &uid, NULL)) {
+	if (e_cal_create_object (client, e_cal_component_get_icalcomponent (comp), &uid, &error)) {
+		gboolean strip_alarms = TRUE;
+
 		if (uid) {
 			e_cal_component_set_uid (comp, uid);
 			g_free (uid);
 		}
 
-		if ((itip_organizer_is_user (comp, client) || itip_sentby_is_user (comp)) &&
+		if ((itip_organizer_is_user (comp, client) || itip_sentby_is_user (comp, client)) &&
 		    send_component_dialog ((GtkWindow *) gtk_widget_get_toplevel (GTK_WIDGET (cal_view)),
-					   client, comp, TRUE)) {
+					   client, comp, TRUE, &strip_alarms)) {
 			itip_send_comp (E_CAL_COMPONENT_METHOD_REQUEST, comp,
-				client, NULL, NULL, NULL);
+				client, NULL, NULL, NULL, strip_alarms);
 		}
 	} else {
-		g_message (G_STRLOC ": Could not create the object!");
+		g_message (G_STRLOC ": Could not create the object! %s", error ? error->message : "");
+		if (error)
+			g_error_free (error);
 	}
 
 	g_object_unref (comp);
@@ -578,7 +566,7 @@ e_calendar_view_set_status_message (ECalendarView *cal_view, const gchar *messag
 			priv->activity_id = 0;
 		}
 	} else if (priv->activity_id == 0) {
-		char *client_id = g_strdup_printf ("%p", cal_view);
+		char *client_id = g_strdup_printf ("%p", (gpointer) cal_view);
 
 		priv->activity_id = e_activity_handler_operation_started (
 			priv->activity_handler, client_id, message, TRUE);
@@ -681,11 +669,11 @@ e_calendar_view_cut_clipboard (ECalendarView *cal_view)
 		comp = e_cal_component_new ();
 		e_cal_component_set_icalcomponent (comp, icalcomponent_new_clone (event->comp_data->icalcomp));
 
-		if ((itip_organizer_is_user (comp, event->comp_data->client) || itip_sentby_is_user (comp))
+		if ((itip_organizer_is_user (comp, event->comp_data->client) || itip_sentby_is_user (comp, event->comp_data->client))
 		    && cancel_component_dialog ((GtkWindow *) gtk_widget_get_toplevel (GTK_WIDGET (cal_view)),
 						event->comp_data->client, comp, TRUE))
 			itip_send_comp (E_CAL_COMPONENT_METHOD_CANCEL, comp,
-					event->comp_data->client, NULL, NULL, NULL);
+					event->comp_data->client, NULL, NULL, NULL, TRUE);
 
 		e_cal_component_get_uid (comp, &uid);
 		if (e_cal_component_is_instance (comp)) {
@@ -745,6 +733,52 @@ clipboard_get_calendar_cb (GtkClipboard *clipboard,
 	}
 }
 
+static void
+add_related_timezones (icalcomponent *des_icalcomp, icalcomponent *src_icalcomp, ECal *client)
+{
+	icalproperty_kind look_in[] = {
+		ICAL_DTSTART_PROPERTY,
+		ICAL_DTEND_PROPERTY,
+		ICAL_NO_PROPERTY
+	};
+	int i;
+
+	g_return_if_fail (des_icalcomp != NULL);
+	g_return_if_fail (src_icalcomp != NULL);
+	g_return_if_fail (client != NULL);
+
+	for (i = 0; look_in[i] != ICAL_NO_PROPERTY; i++) {
+		icalproperty *prop = icalcomponent_get_first_property (src_icalcomp, look_in[i]);
+
+		if (prop) {
+			icalparameter *par = icalproperty_get_first_parameter (prop, ICAL_TZID_PARAMETER);
+
+			if (par) {
+				const char *tzid = icalparameter_get_tzid (par);
+
+				if (tzid) {
+					GError *error = NULL;
+					icaltimezone *zone = NULL;
+
+					if (!e_cal_get_timezone (client, tzid, &zone, &error)) {
+						g_warning ("%s: Cannot get timezone for '%s'. %s", G_STRFUNC, tzid, error ? error->message : "");
+						if (error)
+							g_error_free (error);
+					} else if (zone &&
+						icalcomponent_get_timezone (des_icalcomp, icaltimezone_get_tzid (zone)) == NULL) {
+						/* do not duplicate timezones in the component */
+						icalcomponent *vtz_comp;
+
+						vtz_comp = icaltimezone_get_component (zone);
+						if (vtz_comp)
+							icalcomponent_add_component (des_icalcomp, icalcomponent_new_clone (vtz_comp));
+					}
+				}
+			}
+		}
+	}
+}
+
 void
 e_calendar_view_copy_clipboard (ECalendarView *cal_view)
 {
@@ -766,8 +800,11 @@ e_calendar_view_copy_clipboard (ECalendarView *cal_view)
 	for (l = selected; l != NULL; l = l->next) {
 		event = (ECalendarViewEvent *) l->data;
 
-		if (event)
+		if (event) {
 			e_cal_util_add_timezones_from_component (vcal_comp, event->comp_data->icalcomp);
+
+			add_related_timezones (vcal_comp, event->comp_data->icalcomp, event->comp_data->client);
+		}
 	}
 
 	for (l = selected; l != NULL; l = l->next) {
@@ -788,7 +825,7 @@ e_calendar_view_copy_clipboard (ECalendarView *cal_view)
 
 	/* copy the VCALENDAR to the clipboard */
 	clipboard = gtk_widget_get_clipboard (GTK_WIDGET (cal_view), GDK_SELECTION_CLIPBOARD);
-	comp_str = icalcomponent_as_ical_string (vcal_comp);
+	comp_str = icalcomponent_as_ical_string_r (vcal_comp);
 
 	if (!gtk_clipboard_set_with_data (clipboard, target_types, n_target_types,
 					  clipboard_get_calendar_cb,
@@ -840,40 +877,42 @@ clipboard_get_calendar_data (ECalendarView *cal_view, const gchar *text)
 	else
 		in_top_canvas = FALSE;
 
-	/* FIXME Timezone handling */
 	if (kind == ICAL_VCALENDAR_COMPONENT) {
-		icalcomponent_kind child_kind;
 		icalcomponent *subcomp;
 
-		subcomp = icalcomponent_get_first_component (icalcomp, ICAL_ANY_COMPONENT);
-		while (subcomp) {
-			child_kind = icalcomponent_isa (subcomp);
-			if (child_kind == ICAL_VEVENT_COMPONENT) {
+		/* add timezones first, to have them ready */
+		for (subcomp = icalcomponent_get_first_component (icalcomp, ICAL_VTIMEZONE_COMPONENT);
+		     subcomp;
+		     subcomp = icalcomponent_get_next_component (icalcomp, ICAL_VTIMEZONE_COMPONENT)) {
+			icaltimezone *zone;
+			GError *error = NULL;
 
-				if (e_cal_util_component_has_recurrences (subcomp)) {
-					icalproperty *icalprop = icalcomponent_get_first_property (subcomp, ICAL_RRULE_PROPERTY);
-					if (icalprop)
-						icalproperty_remove_parameter_by_name (icalprop, "X-EVOLUTION-ENDDATE");
-				}
+			zone = icaltimezone_new ();
+			icaltimezone_set_component (zone, subcomp);
+			if (!e_cal_add_timezone (client, zone, &error)) {
+				icalproperty *tzidprop = icalcomponent_get_first_property (subcomp, ICAL_TZID_PROPERTY);
 
-				e_calendar_view_add_event (cal_view, client, selected_time_start,
-							   default_zone, subcomp, in_top_canvas);
-			} else if (child_kind == ICAL_VTIMEZONE_COMPONENT) {
-				icaltimezone *zone;
-
-				zone = icaltimezone_new ();
-				icaltimezone_set_component (zone, subcomp);
-				e_cal_add_timezone (client, zone, NULL);
-
-				icaltimezone_free (zone, 1);
+				g_warning ("%s: Add zone '%s' failed. %s", G_STRFUNC, tzidprop ? icalproperty_get_tzid (tzidprop) : "???", error ? error->message : "");
+				if (error)
+					g_error_free (error);
 			}
 
-			subcomp = icalcomponent_get_next_component (
-				icalcomp, ICAL_ANY_COMPONENT);
+			icaltimezone_free (zone, 1);
+		}
+
+		for (subcomp = icalcomponent_get_first_component (icalcomp, ICAL_VEVENT_COMPONENT);
+		     subcomp;
+		     subcomp = icalcomponent_get_next_component (icalcomp, ICAL_VEVENT_COMPONENT)) {
+			if (e_cal_util_component_has_recurrences (subcomp)) {
+				icalproperty *icalprop = icalcomponent_get_first_property (subcomp, ICAL_RRULE_PROPERTY);
+				if (icalprop)
+					icalproperty_remove_parameter_by_name (icalprop, "X-EVOLUTION-ENDDATE");
+			}
+
+			e_calendar_view_add_event (cal_view, client, selected_time_start, default_zone, subcomp, in_top_canvas);
 		}
 
 		icalcomponent_free (icalcomp);
-
 	} else {
 		e_calendar_view_add_event (cal_view, client, selected_time_start, default_zone, icalcomp, in_top_canvas);
 	}
@@ -966,9 +1005,6 @@ check_for_retract (ECalComponent *comp, ECal *client)
 		ret_val = TRUE;
 	}
 
-	if (!ret_val)
-		ret_val = e_account_list_find(itip_addresses_get(), E_ACCOUNT_FIND_ID_ADDRESS, strip) != NULL;
-
 	g_free (email);
 	return ret_val;
 }
@@ -989,11 +1025,12 @@ delete_event (ECalendarView *cal_view, ECalendarViewEvent *event)
 	if (!e_cal_get_static_capability (event->comp_data->client, CAL_STATIC_CAPABILITY_RECURRENCES_NO_MASTER))
 		e_cal_component_set_recurid (comp, NULL);
 
+	/*FIXME Retract should be moved to Groupwise features plugin */
 	if (check_for_retract (comp, event->comp_data->client)) {
 		char *retract_comment = NULL;
 		gboolean retract = FALSE;
 
-		retract = prompt_retract_dialog (comp, &retract_comment, GTK_WIDGET (cal_view));
+		delete = prompt_retract_dialog (comp, &retract_comment, GTK_WIDGET (cal_view), &retract);
 		if (retract) {
 			GList *users = NULL;
 			icalcomponent *icalcomp = NULL, *mod_comp = NULL;
@@ -1024,12 +1061,12 @@ delete_event (ECalendarView *cal_view, ECalendarViewEvent *event)
 		const char *uid;
 		char *rid = NULL;
 
-		if ((itip_organizer_is_user (comp, event->comp_data->client) || itip_sentby_is_user (comp))
+		if ((itip_organizer_is_user (comp, event->comp_data->client) || itip_sentby_is_user (comp, event->comp_data->client))
 		    && cancel_component_dialog ((GtkWindow *) gtk_widget_get_toplevel (GTK_WIDGET (cal_view)),
 						event->comp_data->client,
 						comp, TRUE))
 			itip_send_comp (E_CAL_COMPONENT_METHOD_CANCEL, comp,
-					event->comp_data->client, NULL, NULL, NULL);
+					event->comp_data->client, NULL, NULL, NULL, TRUE);
 
 		e_cal_component_get_uid (comp, &uid);
 		if (!uid || !*uid) {
@@ -1105,11 +1142,12 @@ e_calendar_view_delete_selected_occurrence (ECalendarView *cal_view)
 	e_cal_component_set_icalcomponent (comp, icalcomponent_new_clone (event->comp_data->icalcomp));
 	vtype = e_cal_component_get_vtype (comp);
 
+	/*FIXME Retract should be moved to Groupwise features plugin */
 	if (check_for_retract (comp, event->comp_data->client)) {
 		char *retract_comment = NULL;
 		gboolean retract = FALSE;
 
-		retract = prompt_retract_dialog (comp, &retract_comment, GTK_WIDGET (cal_view));
+		delete = prompt_retract_dialog (comp, &retract_comment, GTK_WIDGET (cal_view), &retract);
 		if (retract) {
 			GList *users = NULL;
 			icalcomponent *icalcomp = NULL, *mod_comp = NULL;
@@ -1163,7 +1201,7 @@ e_calendar_view_delete_selected_occurrence (ECalendarView *cal_view)
 		e_cal_component_free_datetime (&dt);
 
 
-		if ((itip_organizer_is_user (comp, event->comp_data->client) || itip_sentby_is_user (comp))
+		if ((itip_organizer_is_user (comp, event->comp_data->client) || itip_sentby_is_user (comp, event->comp_data->client))
 				&& cancel_component_dialog ((GtkWindow *) gtk_widget_get_toplevel (GTK_WIDGET (cal_view)),
 					event->comp_data->client,
 					comp, TRUE) && !e_cal_get_save_schedules (event->comp_data->client)) {
@@ -1178,7 +1216,7 @@ e_calendar_view_delete_selected_occurrence (ECalendarView *cal_view)
 
 				e_cal_component_free_datetime (&range.datetime);
 			}
-			itip_send_comp (E_CAL_COMPONENT_METHOD_CANCEL, comp, event->comp_data->client, NULL, NULL, NULL);
+			itip_send_comp (E_CAL_COMPONENT_METHOD_CANCEL, comp, event->comp_data->client, NULL, NULL, NULL, TRUE);
 		}
 
 		if (is_instance)
@@ -1350,7 +1388,28 @@ transfer_item_to (ECalendarViewEvent *event, ECal *dest_client, gboolean remove_
 		if (!e_cal_modify_object (dest_client, event->comp_data->icalcomp, CALOBJ_MOD_ALL, NULL))
 			return;
 	} else {
-		orig_icalcomp = icalcomponent_new_clone (event->comp_data->icalcomp);
+		if (e_cal_util_component_is_instance (event->comp_data->icalcomp)) {
+			icalcomponent *icalcomp = NULL;
+
+			if (e_cal_get_object (event->comp_data->client, uid, NULL, &icalcomp, NULL)) {
+				/* use master object when working with recurring event */
+				orig_icalcomp = icalcomponent_new_clone (icalcomp);
+				icalcomponent_free (icalcomp);
+			} else {
+				/* ... or remove the recurrence id property... */
+				orig_icalcomp = icalcomponent_new_clone (event->comp_data->icalcomp);
+
+				if (e_cal_util_component_has_recurrences (orig_icalcomp)) {
+					/* ... for non-detached instances, to make it a master object */
+					icalproperty *prop;
+
+					prop = icalcomponent_get_first_property (orig_icalcomp, ICAL_RECURRENCEID_PROPERTY);
+					if (prop)
+						icalcomponent_remove_property (orig_icalcomp, prop);
+				}
+			}
+		} else
+			orig_icalcomp = icalcomponent_new_clone (event->comp_data->icalcomp);
 
 		icalprop = icalproperty_new_x ("1");
 		icalproperty_set_x_name (icalprop, "X-EVOLUTION-MOVE-CALENDAR");
@@ -1377,10 +1436,16 @@ transfer_item_to (ECalendarViewEvent *event, ECal *dest_client, gboolean remove_
 
 	/* remove the item from the source calendar */
 	if (remove_item) {
-		if (e_cal_util_component_is_instance (event->comp_data->icalcomp) || e_cal_util_component_is_instance (event->comp_data->icalcomp))
-			e_cal_remove_object_with_mod (event->comp_data->client, uid,
-					NULL, CALOBJ_MOD_ALL, NULL);
-		else
+		if (e_cal_util_component_is_instance (event->comp_data->icalcomp) || e_cal_util_component_has_recurrences (event->comp_data->icalcomp)) {
+			char *rid = NULL;
+			struct icaltimetype recur_id = icalcomponent_get_recurrenceid (event->comp_data->icalcomp);
+
+			if (!icaltime_is_null_time (recur_id))
+				rid = icaltime_as_ical_string_r (recur_id);
+
+			e_cal_remove_object_with_mod (event->comp_data->client, uid, rid, CALOBJ_MOD_ALL, NULL);
+			g_free (rid);
+		} else
 			e_cal_remove_object (event->comp_data->client, uid, NULL);
 	}
 }
@@ -1535,7 +1600,7 @@ on_delegate (EPopup *ep, EPopupItem *pitem, void *data)
 
 		flags |= COMP_EDITOR_MEETING | COMP_EDITOR_DELEGATE;
 
-		open_event_with_flags (cal_view, event->comp_data->client, clone, flags);
+		e_calendar_view_open_event_with_flags (cal_view, event->comp_data->client, clone, flags);
 
 		icalcomponent_free (clone);
 		g_list_free (selected);
@@ -1555,7 +1620,7 @@ on_forward (EPopup *ep, EPopupItem *pitem, void *data)
 
 		comp = e_cal_component_new ();
 		e_cal_component_set_icalcomponent (comp, icalcomponent_new_clone (event->comp_data->icalcomp));
-		itip_send_comp (E_CAL_COMPONENT_METHOD_PUBLISH, comp, event->comp_data->client, NULL, NULL, NULL);
+		itip_send_comp (E_CAL_COMPONENT_METHOD_PUBLISH, comp, event->comp_data->client, NULL, NULL, NULL, TRUE);
 
 		g_list_free (selected);
 		g_object_unref (comp);
@@ -1663,10 +1728,10 @@ on_unrecur_appointment (EPopup *ep, EPopupItem *pitem, void *data)
 
 	*date.value = icaltime_from_timet_with_zone (event->comp_data->instance_start, FALSE,
 						     e_calendar_view_get_timezone (cal_view));
-	e_cal_component_set_dtstart (new_comp, &date);
+	cal_comp_set_dtstart_with_oldzone (client, new_comp, &date);
 	*date.value = icaltime_from_timet_with_zone (event->comp_data->instance_end, FALSE,
 						     e_calendar_view_get_timezone (cal_view));
-	e_cal_component_set_dtend (new_comp, &date);
+	cal_comp_set_dtend_with_oldzone (client, new_comp, &date);
 	e_cal_component_commit_sequence (new_comp);
 
 	/* Now update both ECalComponents. Note that we do this last since at
@@ -1946,7 +2011,7 @@ e_calendar_view_new_appointment_for (ECalendarView *cal_view,
 		flags |= COMP_EDITOR_USER_ORG;
 	}
 
-	open_event_with_flags (cal_view, default_client,
+	e_calendar_view_open_event_with_flags (cal_view, default_client,
 			icalcomp, flags);
 
 	g_object_unref (comp);
@@ -1990,7 +2055,7 @@ e_calendar_view_new_appointment_full (ECalendarView *cal_view, gboolean all_day,
 
 	/* We either need rounding or don't want to set all_day for this, we will rather use actual */
 	/* time in this cases; dtstart should be a midnight in this case */
-	if (do_rounding || (!all_day && (dtend - dtstart) % (60 * 60 * 24) == 0)) {
+	if (do_rounding || (!all_day && (dtend - dtstart) == (60 * 60 * 24))) {
 		struct tm local = *localtime (&now);
 		int time_div = calendar_config_get_time_divisions ();
 		int hours, mins;
@@ -2035,8 +2100,8 @@ object_created_cb (CompEditor *ce, ECalendarView *cal_view)
 	gnome_calendar_emit_user_created_signal (cal_view, e_calendar_view_get_calendar (cal_view), comp_editor_get_client (ce));
 }
 
-static void
-open_event_with_flags (ECalendarView *cal_view, ECal *client, icalcomponent *icalcomp, guint32 flags)
+CompEditor *
+e_calendar_view_open_event_with_flags (ECalendarView *cal_view, ECal *client, icalcomponent *icalcomp, guint32 flags)
 {
 	CompEditor *ce;
 	const char *uid;
@@ -2064,6 +2129,7 @@ open_event_with_flags (ECalendarView *cal_view, ECal *client, icalcomponent *ica
 
 	gtk_window_present (GTK_WINDOW (ce));
 
+	return ce;
 }
 
 /**
@@ -2092,13 +2158,13 @@ e_calendar_view_edit_appointment (ECalendarView *cal_view,
 		ECalComponent *comp = e_cal_component_new ();
 		e_cal_component_set_icalcomponent (comp, icalcomponent_new_clone (icalcomp));
 		flags |= COMP_EDITOR_MEETING;
-		if (itip_organizer_is_user (comp, client) || itip_sentby_is_user (comp) || !e_cal_component_has_attendees (comp))
+		if (itip_organizer_is_user (comp, client) || itip_sentby_is_user (comp, client) || !e_cal_component_has_attendees (comp))
 			flags |= COMP_EDITOR_USER_ORG;
 		g_object_unref (comp);
 	}
 
 
-	open_event_with_flags (cal_view, client, icalcomp, flags);
+	e_calendar_view_open_event_with_flags (cal_view, client, icalcomp, flags);
 }
 
 void
@@ -2109,8 +2175,10 @@ e_calendar_view_modify_and_send (ECalComponent *comp,
 				 gboolean new)
 {
 	if (e_cal_modify_object (client, e_cal_component_get_icalcomponent (comp), mod, NULL)) {
-		if ((itip_organizer_is_user (comp, client) || itip_sentby_is_user (comp)) &&
-		    send_component_dialog (toplevel, client, comp, new)) {
+		gboolean strip_alarms = TRUE;
+
+		if ((itip_organizer_is_user (comp, client) || itip_sentby_is_user (comp, client)) &&
+		    send_component_dialog (toplevel, client, comp, new, &strip_alarms)) {
 			ECalComponent *send_comp = NULL;
 
 			if (mod == CALOBJ_MOD_ALL && e_cal_component_is_instance (comp)) {
@@ -2129,7 +2197,7 @@ e_calendar_view_modify_and_send (ECalComponent *comp,
 				}
 			}
 
-			itip_send_comp (E_CAL_COMPONENT_METHOD_REQUEST, send_comp ? send_comp : comp, client, NULL, NULL, NULL);
+			itip_send_comp (E_CAL_COMPONENT_METHOD_REQUEST, send_comp ? send_comp : comp, client, NULL, NULL, NULL, strip_alarms);
 
 			if (send_comp)
 				g_object_unref (send_comp);
@@ -2213,7 +2281,7 @@ e_calendar_view_move_tip (GtkWidget *widget, int x, int y)
  * Free returned pointer with g_free.
  **/
 char *
-e_calendar_view_get_attendees_status_info (ECalComponent *comp)
+e_calendar_view_get_attendees_status_info (ECalComponent *comp, ECal *client)
 {
 	struct _values {
 		icalparameter_partstat status;
@@ -2234,7 +2302,7 @@ e_calendar_view_get_attendees_status_info (ECalComponent *comp)
 	char *res = NULL;
 	int i;
 
-	if (!comp || !e_cal_component_has_attendees (comp))
+	if (!comp || !e_cal_component_has_attendees (comp) || !itip_organizer_is_user_ex (comp, client, TRUE))
 		return NULL;
 
 	e_cal_component_get_attendee_list (comp, &attendees);
@@ -2415,13 +2483,25 @@ e_calendar_view_get_tooltips (ECalendarViewEventData *data)
 	tmp1 = get_label(dtstart.value, zone, default_zone);
 	tmp = calculate_time (t_start, t_end);
 
+	/* To Translators: It will display "Time: ActualStartDateAndTime (DurationOfTheMeeting)"*/
+	tmp2 = g_strdup_printf(_("Time: %s %s"), tmp1, tmp);
+	if (zone && !cal_comp_util_compare_event_timezones (newcomp, client, default_zone)) {
+		g_free (tmp);
+		g_free (tmp1);
+
+		tmp1 = get_label (dtstart.value, zone, zone);
+		tmp = g_strconcat (tmp2, "\n\t[ ", tmp1, " ", icaltimezone_get_display_name (zone), " ]", NULL);
+	} else {
+		g_free (tmp);
+		tmp = tmp2;
+		tmp2 = NULL;
+	}
+
 	e_cal_component_free_datetime (&dtstart);
 	e_cal_component_free_datetime (&dtend);
 
-	/* To Translators: It will display "Time: ActualStartDateAndTime (DurationOfTheMeeting)"*/
-	tmp2 = g_strdup_printf(_("Time: %s %s"), tmp1, tmp);
 	hbox = gtk_hbox_new (FALSE, 0);
-	gtk_box_pack_start ((GtkBox *)hbox, gtk_label_new_with_mnemonic (tmp2), FALSE, FALSE, 0);
+	gtk_box_pack_start ((GtkBox *)hbox, gtk_label_new_with_mnemonic (tmp), FALSE, FALSE, 0);
 	ebox = gtk_event_box_new ();
 	gtk_container_add ((GtkContainer *)ebox, hbox);
 	gtk_box_pack_start ((GtkBox *)box, ebox, FALSE, FALSE, 0);
@@ -2430,7 +2510,7 @@ e_calendar_view_get_tooltips (ECalendarViewEventData *data)
 	g_free (tmp2);
 	g_free (tmp1);
 
-	tmp = e_calendar_view_get_attendees_status_info (newcomp);
+	tmp = e_calendar_view_get_attendees_status_info (newcomp, pevent->comp_data->client);
 	if (tmp) {
 		hbox = gtk_hbox_new (FALSE, 0);
 		gtk_box_pack_start ((GtkBox *)hbox, gtk_label_new (tmp), FALSE, FALSE, 0);
@@ -2475,7 +2555,7 @@ icalcomp_contains_category (icalcomponent *icalcomp, const gchar *category)
 	for (property = icalcomponent_get_first_property (icalcomp, ICAL_CATEGORIES_PROPERTY);
 	     property != NULL;
 	     property = icalcomponent_get_next_property (icalcomp, ICAL_CATEGORIES_PROPERTY)) {
-		char *value = icalproperty_get_value_as_string (property);
+		char *value = icalproperty_get_value_as_string_r (property);
 
 		if (value && strcmp (category, value) == 0){
 			g_free (value);
@@ -2580,10 +2660,7 @@ draw_curved_rectangle (cairo_t *cr, double x0, double y0,
 static void 
 error_response(GtkWidget *widget, gint response, void *data)
 {
-	if (response == GTK_RESPONSE_DELETE_EVENT) 
-		gtk_widget_destroy(widget);
-	else if (response == GTK_RESPONSE_OK) 
-		gtk_widget_destroy(widget);
+	gtk_widget_destroy (widget);
 }
 
 void
