@@ -1,26 +1,25 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-
 /*
- * Authors :
- *  Damon Chaplin <damon@ximian.com>
- *  Rodrigo Moya <rodrigo@ximian.com>
- *  Nathan Owens <pianocomp81@yahoo.com>
- *
- * Copyright 2000, 2001, 2002, 2003 Novell, Inc.
- *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ *
+ *
+ * Authors:
+ *		Damon Chaplin <damon@ximian.com>
+ *		Rodrigo Moya <rodrigo@ximian.com>
+ *		Nathan Owens <pianocomp81@yahoo.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
- * USA
  */
 
 /*
@@ -37,7 +36,6 @@
 #include <glib/gi18n.h>
 #include <glib/gstdio.h>
 #include <gdk/gdkkeysyms.h>
-#include <libgnome/gnome-url.h>
 #include <widgets/misc/e-gui-utils.h>
 #include <table/e-cell-checkbox.h>
 #include <table/e-cell-toggle.h>
@@ -59,6 +57,7 @@
 #include <e-util/e-icon-factory.h>
 #include <e-util/e-util-private.h>
 #include "e-cal-popup.h"
+#include "e-calendar-table.h"
 
 enum TargetType{
 	TARGET_TYPE_VCALENDAR
@@ -183,6 +182,18 @@ row_appended_cb (ECalModel *model, EMemoTable *memo_table)
 	g_signal_emit (memo_table, signals[USER_CREATED], 0);
 }
 
+static gboolean
+query_tooltip_cb (GtkWidget *widget, gint x, gint y, gboolean keyboard_mode, GtkTooltip *tooltip, gpointer user_data)
+{
+	EMemoTable *memo_table;
+
+	g_return_val_if_fail (E_IS_MEMO_TABLE (user_data), FALSE);
+
+	memo_table = E_MEMO_TABLE (user_data);
+
+	return ec_query_tooltip (widget, x, y, keyboard_mode, tooltip, GTK_WIDGET (e_memo_table_get_table (memo_table)), memo_table->model);
+}
+
 static void
 e_memo_table_init (EMemoTable *memo_table)
 {
@@ -241,7 +252,7 @@ e_memo_table_init (EMemoTable *memo_table)
 
 	if (!icon_pixbufs[0])
 		for (i = 0; i < E_MEMO_MODEL_NUM_ICONS; i++) {
-			icon_pixbufs[i] = e_icon_factory_get_icon (icon_names[i], E_ICON_SIZE_LIST);
+			icon_pixbufs[i] = e_icon_factory_get_icon (icon_names[i], GTK_ICON_SIZE_MENU);
 		}
 
 	cell = e_cell_toggle_new (0, E_MEMO_MODEL_NUM_ICONS, icon_pixbufs);
@@ -274,6 +285,8 @@ e_memo_table_init (EMemoTable *memo_table)
 	g_signal_connect (e_table, "right_click", G_CALLBACK (e_memo_table_on_right_click), memo_table);
 	g_signal_connect (e_table, "key_press", G_CALLBACK (e_memo_table_on_key_press), memo_table);
 	g_signal_connect (e_table, "popup_menu", G_CALLBACK (e_memo_table_on_popup_menu), memo_table);
+	g_signal_connect (e_table, "query-tooltip", G_CALLBACK (query_tooltip_cb), memo_table);
+	gtk_widget_set_has_tooltip (GTK_WIDGET (e_table), TRUE);
 
 	a11y = gtk_widget_get_accessible (GTK_WIDGET(e_table));
 	if (a11y)
@@ -548,7 +561,7 @@ copy_row_cb (int model_row, gpointer data)
 	e_cal_util_add_timezones_from_component (memo_table->tmp_vcal, comp_data->icalcomp);
 
 	/* add the new component to the VCALENDAR component */
-	comp_str = icalcomponent_as_ical_string (comp_data->icalcomp);
+	comp_str = icalcomponent_as_ical_string_r (comp_data->icalcomp);
 	child = icalparser_parse_string (comp_str);
 	if (child) {
 		icalcomponent_add_component (memo_table->tmp_vcal,
@@ -598,13 +611,12 @@ e_memo_table_copy_clipboard (EMemoTable *memo_table)
 
 	etable = e_table_scrolled_get_table (E_TABLE_SCROLLED (memo_table->etable));
 	e_table_selected_row_foreach (etable, copy_row_cb, memo_table);
-	comp_str = icalcomponent_as_ical_string (memo_table->tmp_vcal);
+	comp_str = icalcomponent_as_ical_string_r (memo_table->tmp_vcal);
 	clipboard = gtk_widget_get_clipboard (GTK_WIDGET (memo_table), clipboard_atom);
 	if (!gtk_clipboard_set_with_data(clipboard, target_types, n_target_types,
 					 clipboard_get_calendar_cb,
 					 NULL, comp_str)) {
-		/* do not free this pointer, it owns libical */
-		/* g_free (comp_str); */
+		/* no-op */
 	} else {
 		gtk_clipboard_set_can_store (clipboard, target_types + 1, n_target_types - 1);
 	}
@@ -763,7 +775,7 @@ open_memo (EMemoTable *memo_table, ECalModelComponent *comp_data)
 		if (itip_organizer_is_user (comp, comp_data->client))
 			flags |= COMP_EDITOR_USER_ORG;
 
-		medit = COMP_EDITOR (memo_editor_new (comp_data->client, flags));
+		medit = memo_editor_new (comp_data->client, flags);
 
 		comp_editor_edit_comp (medit, comp);
 		g_object_unref (comp);
@@ -771,7 +783,7 @@ open_memo (EMemoTable *memo_table, ECalModelComponent *comp_data)
 		e_comp_editor_registry_add (comp_editor_registry, medit, FALSE);
 	}
 
-	comp_editor_focus (medit);
+	gtk_window_present (GTK_WINDOW (medit));
 }
 
 /* Opens the task in the specified row */
@@ -886,7 +898,7 @@ e_memo_table_on_forward (EPopup *ep, EPopupItem *pitem, void *data)
 
 		comp = e_cal_component_new ();
 		e_cal_component_set_icalcomponent (comp, icalcomponent_new_clone (comp_data->icalcomp));
-		itip_send_comp (E_CAL_COMPONENT_METHOD_PUBLISH, comp, comp_data->client, NULL, NULL, NULL);
+		itip_send_comp (E_CAL_COMPONENT_METHOD_PUBLISH, comp, comp_data->client, NULL, NULL, NULL, TRUE);
 
 		g_object_unref (comp);
 	}
@@ -908,7 +920,8 @@ open_url_cb (EPopup *ep, EPopupItem *pitem, void *data)
 	if (!prop)
 		return;
 
-	gnome_url_show (icalproperty_get_url (prop), NULL);
+	/* FIXME Pass a parent window. */
+	e_show_uri (NULL, icalproperty_get_url (prop));
 }
 
 /* Callback for the "delete tasks" menu item */
@@ -1095,10 +1108,6 @@ static char *test[] = {
 
 #endif
 
-/* Displays messages on the status bar */
-#define EVOLUTION_MEMOS_PROGRESS_IMAGE "stock_notes"
-static GdkPixbuf *progress_icon = NULL;
-
 void
 e_memo_table_set_activity_handler (EMemoTable *memo_table, EActivityHandler *activity_handler)
 {
@@ -1121,13 +1130,10 @@ e_memo_table_set_status_message (EMemoTable *memo_table, const gchar *message)
 			memo_table->activity_id = 0;
 		}
         } else if (memo_table->activity_id == 0) {
-                char *client_id = g_strdup_printf ("%p", memo_table);
+                char *client_id = g_strdup_printf ("%p", (gpointer) memo_table);
 
-                if (progress_icon == NULL)
-                        progress_icon = e_icon_factory_get_icon (EVOLUTION_MEMOS_PROGRESS_IMAGE, E_ICON_SIZE_STATUS);
-
-                memo_table->activity_id = e_activity_handler_operation_started (memo_table->activity_handler, client_id,
-									        progress_icon, message, TRUE);
+                memo_table->activity_id = e_activity_handler_operation_started (
+			memo_table->activity_handler, client_id, message, TRUE);
 
                 g_free (client_id);
         } else {
