@@ -26,7 +26,7 @@
 
 #include <errno.h>
 #include <string.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <bonobo/bonobo-control.h>
 #include <bonobo/bonobo-exception.h>
 #include <gconf/gconf-client.h>
@@ -58,7 +58,7 @@
 #define CREATE_TASK_LIST_ID          "task-list"
 
 enum DndTargetType {
-	DND_TARGET_TYPE_CALENDAR_LIST,
+	DND_TARGET_TYPE_CALENDAR_LIST
 };
 #define CALENDAR_TYPE "text/calendar"
 #define XCALENDAR_TYPE "text/x-calendar"
@@ -120,17 +120,12 @@ struct _TasksComponentPrivate {
 static void
 ensure_sources (TasksComponent *component)
 {
-	GSList *groups;
 	ESourceList *source_list;
-	ESourceGroup *group;
 	ESourceGroup *on_this_computer;
-	ESourceGroup *on_the_web;
 	ESource *personal_source;
-	char *base_uri, *base_uri_proto;
+	char *base_uri, *base_uri_proto, base_uri_proto_seventh;
 	const gchar *base_dir;
 
-	on_this_computer = NULL;
-	on_the_web = NULL;
 	personal_source = NULL;
 
 	if (!e_cal_get_sources (&source_list, E_CAL_SOURCE_TYPE_TODO, NULL)) {
@@ -142,24 +137,20 @@ ensure_sources (TasksComponent *component)
 	base_uri = g_build_filename (base_dir, "local", NULL);
 
 	base_uri_proto = g_filename_to_uri (base_uri, NULL, NULL);
+	if (strlen (base_uri_proto) > 7) {
+		/* compare only file:// part. If user home dir name changes we do not want to create
+		   one more group  */
+		base_uri_proto_seventh = base_uri_proto[7];
+		base_uri_proto[7] = 0;
+	} else {
+		base_uri_proto_seventh = -1;
+	}
 
-	groups = e_source_list_peek_groups (source_list);
-	if (groups) {
-		/* groups are already there, we need to search for things... */
-		GSList *g;
+	on_this_computer = e_source_list_ensure_group (source_list, _("On This Computer"), base_uri_proto, TRUE);
+	e_source_list_ensure_group (source_list, _("On The Web"), WEB_BASE_URI, FALSE);
 
-		for (g = groups; g; g = g->next) {
-
-			group = E_SOURCE_GROUP (g->data);
-
-			/* compare only file:// part. If user home dir name changes we do not want to create
-			   one more group  */
-
-			if (!on_this_computer && !strncmp (base_uri_proto, e_source_group_peek_base_uri (group), 7))
-				on_this_computer = group;
-			else if (!on_the_web && !strcmp (WEB_BASE_URI, e_source_group_peek_base_uri (group)))
-				on_the_web = group;
-		}
+	if (base_uri_proto_seventh != -1) {
+		base_uri_proto[7] = base_uri_proto_seventh;
 	}
 
 	if (on_this_computer) {
@@ -190,15 +181,11 @@ ensure_sources (TasksComponent *component)
 		    e_source_list_sync (source_list,NULL);
 		}
 	}
-	else {
-		/* create the local source group */
-		group = e_source_group_new (_("On This Computer"), base_uri_proto);
-		e_source_list_add_group (source_list, group, -1);
 
-		on_this_computer = group;
-	}
-
-	if (!personal_source) {
+	if (personal_source) {
+		/* ensure the source name is in current locale, not read from configuration */
+		e_source_set_name (personal_source, _("Personal"));
+	} else {
 		GSList *tasks_selected;
 		/* Create the default Person addressbook */
 		ESource *source = e_source_new (_("Personal"), PERSONAL_RELATIVE_URI);
@@ -226,15 +213,9 @@ ensure_sources (TasksComponent *component)
 		personal_source = source;
 	}
 
-	if (!on_the_web) {
-		/* Create the LDAP source group */
-		group = e_source_group_new (_("On The Web"), WEB_BASE_URI);
-		e_source_list_add_group (source_list, group, -1);
-
-		on_the_web = group;
-	}
-
 	component->priv->source_list = source_list;
+
+	g_object_unref (on_this_computer);
 	g_free (base_uri_proto);
 	g_free (base_uri);
 }
@@ -628,60 +609,6 @@ impl_upgradeFromVersion (PortableServer_Servant servant,
 		g_error_free(err);
 }
 
-static gboolean
-update_single_object (ECal *client, icalcomponent *icalcomp)
-{
-	char *uid;
-	icalcomponent *tmp_icalcomp;
-
-	uid = (char *) icalcomponent_get_uid (icalcomp);
-
-	if (e_cal_get_object (client, uid, NULL, &tmp_icalcomp, NULL))
-		return e_cal_modify_object (client, icalcomp, CALOBJ_MOD_ALL, NULL);
-
-	return e_cal_create_object (client, icalcomp, &uid, NULL);
-}
-
-static gboolean
-update_objects (ECal *client, icalcomponent *icalcomp)
-{
-	icalcomponent *subcomp;
-	icalcomponent_kind kind;
-
-	kind = icalcomponent_isa (icalcomp);
-	if (kind == ICAL_VTODO_COMPONENT || kind == ICAL_VEVENT_COMPONENT)
-		return update_single_object (client, icalcomp);
-	else if (kind != ICAL_VCALENDAR_COMPONENT)
-		return FALSE;
-
-	subcomp = icalcomponent_get_first_component (icalcomp, ICAL_ANY_COMPONENT);
-	while (subcomp) {
-		gboolean success;
-
-		kind = icalcomponent_isa (subcomp);
-		if (kind == ICAL_VTIMEZONE_COMPONENT) {
-			icaltimezone *zone;
-
-			zone = icaltimezone_new ();
-			icaltimezone_set_component (zone, subcomp);
-
-			success = e_cal_add_timezone (client, zone, NULL);
-			icaltimezone_free (zone, 1);
-			if (!success)
-				return success;
-		} else if (kind == ICAL_VTODO_COMPONENT ||
-			   kind == ICAL_VEVENT_COMPONENT) {
-			success = update_single_object (client, subcomp);
-			if (!success)
-				return success;
-		}
-
-		subcomp = icalcomponent_get_next_component (icalcomp, ICAL_ANY_COMPONENT);
-	}
-
-	return TRUE;
-}
-
 static gboolean
 selector_tree_data_dropped (ESourceSelector *selector,
                             GtkSelectionData *data,
@@ -702,11 +629,8 @@ selector_tree_data_dropped (ESourceSelector *selector,
 		goto  finish;
 
 	components = cal_comp_selection_get_string_list (data);
-	for (p = components; p; p = p->next) {
-		const char * uid;
-		char *old_uid = NULL;
-		icalcomponent *tmp_icalcomp = NULL;
-		GError *error = NULL;
+	success = components != NULL;
+	for (p = components; p && success; p = p->next) {
 		char *comp_str; /* do not free this! */
 
 		/* p->data is "source_uid\ncomponent_string" */
@@ -721,56 +645,7 @@ selector_tree_data_dropped (ESourceSelector *selector,
 		if (!icalcomp)
 			continue;
 
-		/* FIXME deal with GDK_ACTION_ASK */
-		if (action == GDK_ACTION_COPY) {
-			old_uid = g_strdup (icalcomponent_get_uid (icalcomp));
-			uid = e_cal_component_gen_uid ();
-			icalcomponent_set_uid (icalcomp, uid);
-		}
-
-		uid = icalcomponent_get_uid (icalcomp);
-		if (!old_uid)
-			old_uid = g_strdup (uid);
-
-		if (!e_cal_get_object (client, uid, NULL, &tmp_icalcomp, &error)) {
-			if ((error != NULL) && (error->code != E_CALENDAR_STATUS_OBJECT_NOT_FOUND))
-				g_message ("Failed to search the object in destination task list: %s",error->message);
-			else {
-				/* this will report success by last item, but we don't care */
-				success = update_objects (client, icalcomp);
-
-				if (success && action == GDK_ACTION_MOVE) {
-					/* remove components rather here, because we know which has been moved */
-					ESource *source_source;
-					ECal *source_client;
-
-					source_source = e_source_list_peek_source_by_uid (component->priv->source_list, p->data);
-
-					if (source_source && !E_IS_SOURCE_GROUP (source_source) && !e_source_get_readonly (source_source)) {
-						source_client = auth_new_cal_from_source (source_source, E_CAL_SOURCE_TYPE_TODO);
-
-						if (source_client) {
-							gboolean read_only = TRUE;
-
-							e_cal_is_read_only (source_client, &read_only, NULL);
-
-							if (!read_only && e_cal_open (source_client, TRUE, NULL))
-								e_cal_remove_object (source_client, old_uid, NULL);
-							else if (!read_only)
-								g_message ("Cannot open source client to remove old task");
-
-							g_object_unref (source_client);
-						} else
-							g_message ("Cannot create source client to remove old task");
-					}
-				}
-			}
-
-			g_clear_error (&error);
-		} else
-			icalcomponent_free (tmp_icalcomp);
-
-		g_free (old_uid);
+		success = cal_comp_process_source_list_drop (client, icalcomp, action, p->data, component->priv->source_list);
 		icalcomponent_free (icalcomp);
 	}
 	g_slist_foreach (components, (GFunc)g_free, NULL);
@@ -1076,7 +951,6 @@ destroy_component_view (TasksComponentView *component_view)
 {
 	GList *l;
 
-	g_signal_handlers_disconnect_by_func (component_view->table, G_CALLBACK (table_selection_change_cb), component_view);
 	g_signal_handlers_disconnect_matched (component_view->model, G_SIGNAL_MATCH_DATA, 0, 0, 0, 0, component_view);
 
 	if (component_view->source_list)
@@ -1349,6 +1223,9 @@ tasks_component_class_init (TasksComponentClass *klass)
 	POA_GNOME_Evolution_Component__epv *epv = &klass->epv;
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
+	bindtextdomain (GETTEXT_PACKAGE, EVOLUTION_LOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+
 	parent_class = g_type_class_peek_parent (klass);
 
 	epv->upgradeFromVersion      = impl_upgradeFromVersion;
