@@ -1,20 +1,21 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU Lesser General Public
- * License as published by the Free Software Foundation.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ *
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ *
  */
 
 #include "e-composer-name-header.h"
@@ -116,10 +117,12 @@ composer_name_header_constructor (GType type,
 	entry = E_NAME_SELECTOR_ENTRY (
 		e_name_selector_peek_section_list (
 		priv->name_selector, label));
+
 	e_name_selector_entry_set_contact_editor_func (
 		entry, e_contact_editor_new);
 	e_name_selector_entry_set_contact_list_editor_func (
 		entry, e_contact_list_editor_new);
+
 	g_signal_connect (
 		entry, "changed",
 		G_CALLBACK (composer_name_header_entry_changed_cb), object);
@@ -260,6 +263,32 @@ e_composer_name_header_new (const gchar *label,
 		"button", TRUE, "name-selector", name_selector, NULL);
 }
 
+EComposerHeader *
+e_composer_name_header_new_with_label (const gchar *label,
+				  ENameSelector *name_selector)
+{
+	return g_object_new (
+		E_TYPE_COMPOSER_NAME_HEADER, "label", label,
+		"button", FALSE,  "name-selector", name_selector,
+		"addaction", FALSE, "visible", TRUE,
+		NULL);
+}
+
+EComposerHeader *
+e_composer_name_header_new_with_action (const gchar *label,
+					const gchar *action_label,
+					ENameSelector *name_selector)
+{
+	g_return_val_if_fail (E_IS_NAME_SELECTOR (name_selector), NULL);
+
+	return g_object_new (
+		E_TYPE_COMPOSER_NAME_HEADER, "label", label,
+		"button", FALSE, "name-selector", name_selector, 
+		"addaction_text", action_label,
+		"addaction", action_label != NULL,
+		NULL);
+}
+
 ENameSelector *
 e_composer_name_header_get_name_selector (EComposerNameHeader *header)
 {
@@ -293,6 +322,27 @@ e_composer_name_header_get_destinations (EComposerNameHeader *header)
 	return destinations;  /* free with e_destination_freev() */
 }
 
+void
+e_composer_name_header_add_destinations (EComposerNameHeader *header,
+                                         EDestination **destinations)
+{
+	EDestinationStore *store;
+	ENameSelectorEntry *entry;
+	gint ii;
+
+	g_return_if_fail (E_IS_COMPOSER_NAME_HEADER (header));
+
+	entry = E_COMPOSER_NAME_HEADER_GET_ENTRY (header);
+	store = e_name_selector_entry_peek_destination_store (entry);
+
+	if (destinations == NULL)
+		return;
+
+	for (ii = 0; destinations[ii] != NULL; ii++)
+		e_destination_store_append_destination (
+			store, destinations[ii]);
+}
+
 void
 e_composer_name_header_set_destinations (EComposerNameHeader *header,
                                          EDestination **destinations)
@@ -300,7 +350,6 @@ e_composer_name_header_set_destinations (EComposerNameHeader *header,
 	EDestinationStore *store;
 	ENameSelectorEntry *entry;
 	GList *list, *iter;
-	gint ii;
 
 	g_return_if_fail (E_IS_COMPOSER_NAME_HEADER (header));
 
@@ -313,10 +362,5 @@ e_composer_name_header_set_destinations (EComposerNameHeader *header,
 		e_destination_store_remove_destination (store, iter->data);
 	g_list_free (list);
 
-	if (destinations == NULL)
-		return;
-
-	for (ii = 0; destinations[ii] != NULL; ii++)
-		e_destination_store_append_destination (
-			store, destinations[ii]);
+	e_composer_name_header_add_destinations (header, destinations);
 }
