@@ -532,11 +532,13 @@ ec_rebuild(EConfig *emp)
 					gnome_druid_page_edge_set_title((GnomeDruidPageEdge *)page, translated_label);
 					gnome_druid_insert_page((GnomeDruid *)druid, pagenode?(GnomeDruidPage *)pagenode->frame:NULL, (GnomeDruidPage *)page);
 				}
-				if (item->type == E_CONFIG_PAGE_FINISH) {
-					g_signal_connect(page, "back", G_CALLBACK(ec_druid_prev), wn);
-					g_signal_connect(page, "finish", G_CALLBACK(ec_druid_finish), wn);
-				} else
-					g_signal_connect(page, "next", G_CALLBACK(ec_druid_next), wn);
+				if (page) {
+					if (item->type == E_CONFIG_PAGE_FINISH) {
+						g_signal_connect(page, "back", G_CALLBACK(ec_druid_prev), wn);
+						g_signal_connect(page, "finish", G_CALLBACK(ec_druid_finish), wn);
+					} else
+						g_signal_connect(page, "next", G_CALLBACK(ec_druid_next), wn);
+				}
 				wn->frame = page;
 				wn->widget = page;
 			}
@@ -567,10 +569,11 @@ ec_rebuild(EConfig *emp)
 				page = item->factory(emp, item, root, wn->frame, wn->context->data);
 				if (emp->type == E_CONFIG_DRUID) {
 					if (page) {
-						g_return_if_fail (GNOME_IS_DRUID_PAGE_STANDARD(page));
-						connect = wn->frame != page;
-						wn->frame = page;
-						page = ((GnomeDruidPageStandard *)page)->vbox;
+						if (GNOME_IS_DRUID_PAGE_STANDARD(page)) {
+							connect = wn->frame != page;
+							wn->frame = page;
+							page = ((GnomeDruidPageStandard *)page)->vbox;
+						}
 					} else
 						wn->frame = page;
 				} else {
@@ -905,10 +908,10 @@ e_config_create_window(EConfig *emp, struct _GtkWindow *parent, const char *titl
 		g_signal_connect(w, "response", G_CALLBACK(ec_dialog_response), emp);
 
 		gtk_widget_ensure_style (w);
-		gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (w)->vbox), 0);
-		gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (w)->action_area), 12);
+		gtk_container_set_border_width (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG (w))), 0);
+		gtk_container_set_border_width (GTK_CONTAINER (gtk_dialog_get_action_area (GTK_DIALOG (w))), 12);
 
-		gtk_box_pack_start((GtkBox *)((GtkDialog *)w)->vbox, emp->widget, TRUE, TRUE, 0);
+		gtk_box_pack_start((GtkBox *)gtk_dialog_get_content_area (((GtkDialog *)w)), emp->widget, TRUE, TRUE, 0);
 	} else {
 		/* response is handled directly by the druid stuff */
 		w = gtk_window_new(GTK_WINDOW_TOPLEVEL);
