@@ -1,21 +1,22 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- *
+/*
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
- *  Authors: Michael Zucchi <notzed@ximian.com>
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- *  Copyright 2004 Novell Inc. (www.novell.com)
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
  *
- *  This program is free software; you can redistribute it and/or
- *  modify it under the terms of version 2 of the GNU General Public
- *  License as published by the Free Software Foundation.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * Authors:
+ *		Michael Zucchi <notzed@ximian.com>
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
@@ -27,21 +28,12 @@
 #include <libxml/parser.h>
 #include <libxml/xmlmemory.h>
 
-#include <glib.h>
-#include <gtk/gtkbutton.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtkdialog.h>
-#include <gtk/gtkwindow.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtkscrolledwindow.h>
-#include <gtk/gtkwindow.h>
+#include <gtk/gtk.h>
 #include <glib/gi18n.h>
-#include <libgnome/gnome-url.h>
 
 #include <libedataserver/e-xml-utils.h>
 
+#include "e-util.h"
 #include "e-util-private.h"
 #include "e-error.h"
 
@@ -403,15 +395,9 @@ ee_build_label(GString *out, const char *fmt, GPtrArray *args,
 static void
 ee_response(GtkWidget *w, guint button, struct _e_error *e)
 {
-	GError *err = NULL;
-
 	if (button == GTK_RESPONSE_HELP) {
 		g_signal_stop_emission_by_name(w, "response");
-		gnome_url_show(e->help_uri, &err);
-		if (err) {
-			g_warning("Unable to run help uri: %s", err->message);
-			g_error_free(err);
-		}
+		e_display_help (GTK_WINDOW (w), e->help_uri);
 	}
 }
 
@@ -521,8 +507,8 @@ e_error_newv(GtkWindow *parent, const char *tag, const char *arg0, va_list ap)
 
 	out = g_string_new("");
 
-	if (e->title) {
-		ee_build_label(out, dgettext(table->translation_domain, e->title), args, FALSE);
+	if (e->title && *e->title) {
+		ee_build_label(out, e->title, args, FALSE);
 		gtk_window_set_title((GtkWindow *)dialog, out->str);
 		g_string_truncate(out, 0);
 	} else
@@ -531,19 +517,19 @@ e_error_newv(GtkWindow *parent, const char *tag, const char *arg0, va_list ap)
 
 	if (e->primary) {
 		g_string_append(out, "<span weight=\"bold\" size=\"larger\">");
-		ee_build_label(out, dgettext(table->translation_domain, e->primary), args, TRUE);
+		ee_build_label(out, e->primary, args, TRUE);
 		g_string_append(out, "</span>\n\n");
 		oerr = g_string_new("");
-		ee_build_label(oerr, dgettext(table->translation_domain, e->primary), args, FALSE);
+		ee_build_label(oerr, e->primary, args, FALSE);
 		perr = g_strdup (oerr->str);
 		g_string_free (oerr, TRUE);
 	} else
 		perr = g_strdup (gtk_window_get_title (GTK_WINDOW (dialog)));
 	
 	if (e->secondary) {
-		ee_build_label(out, dgettext(table->translation_domain, e->secondary), args, TRUE);
+		ee_build_label(out, e->secondary, args, TRUE);
 		oerr = g_string_new("");
-		ee_build_label(oerr, dgettext(table->translation_domain, e->secondary), args, TRUE);
+		ee_build_label(oerr, e->secondary, args, TRUE);
 		serr = g_strdup (oerr->str);
 		g_string_free (oerr, TRUE);
 	}
