@@ -1,22 +1,22 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /*
- *  Authors: Jeffrey Stedfast <fejj@novell.com>
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
- *  Copyright 2004 Novell, Inc. (www.novell.com)
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * Authors:
+ *		Jeffrey Stedfast <fejj@novell.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
@@ -34,21 +34,14 @@
 #include <libgnomeui/gnome-thumbnail.h>
 #endif
 
+#include <gtk/gtk.h>
+
 #include "e-icon-factory.h"
 #include "e-util-private.h"
 
 #include "art/broken-image-16.xpm"
 #include "art/broken-image-24.xpm"
-
-static int sizes[E_ICON_NUM_SIZES] = {
-	16, /* menu */
-	20, /* button */
-	18, /* small toolbar */
-	24, /* large toolbar */
-	32, /* dnd */
-	48, /* dialog */
-};
-
+#define d(x)
 
 typedef struct {
 	char *name;
@@ -173,23 +166,6 @@ load_icon (const char *icon_key, const char *icon_name, int size, int scale)
 	return icon_new (icon_key, pixbuf);
 }
 
-
-/* temporary workaround for code that has not yet been ported to the new icon_size API */
-static int
-pixel_size_to_icon_size (int pixel_size)
-{
-	int i, icon_size = -1;
-
-	for (i = 0; i < E_ICON_NUM_SIZES; i++) {
-		if (pixel_size == sizes[i]) {
-			icon_size = i;
-			break;
-		}
-	}
-
-	return icon_size;
-}
-
 static void
 icon_theme_changed_cb (GtkIconTheme *icon_theme, gpointer user_data)
 {
@@ -253,39 +229,35 @@ e_icon_factory_shutdown (void)
 /**
  * e_icon_factory_get_icon_filename:
  * @icon_name: name of the icon
- * @size: MENU/SMALL_TOOLBAR/etc
+ * @size: size of the icon
  *
  * Looks up the icon to use based on name and size.
  *
  * Returns the requested icon pixbuf.
  **/
-char *
-e_icon_factory_get_icon_filename (const char *icon_name, int icon_size)
+gchar *
+e_icon_factory_get_icon_filename (const gchar *icon_name,
+                                  GtkIconSize icon_size)
 {
+	GtkIconTheme *icon_theme;
 	GtkIconInfo *icon_info;
-	char *filename;
+	gchar *filename = NULL;
+	gint width, height;
 
 	g_return_val_if_fail (icon_name != NULL, NULL);
-	g_return_val_if_fail (strcmp (icon_name, ""), NULL);
 
-	if (icon_size >= E_ICON_NUM_SIZES) {
-		g_warning (
-			"calling %s with unknown icon_size value (%d)",
-			G_STRFUNC, icon_size);
-		if ((icon_size = pixel_size_to_icon_size (icon_size)) == -1)
-			return NULL;
-	}
+	icon_theme = gtk_icon_theme_get_default ();
+
+	if (!gtk_icon_size_lookup (icon_size, &width, &height))
+		return NULL;
 
-	g_static_mutex_lock (&mutex);
 	icon_info = gtk_icon_theme_lookup_icon (
-		icon_theme, icon_name, sizes[icon_size], 0);
+		icon_theme, icon_name, height, 0);
 	if (icon_info != NULL) {
 		filename = g_strdup (
 			gtk_icon_info_get_filename (icon_info));
 		gtk_icon_info_free (icon_info);
-	} else
-		filename = NULL;
-	g_static_mutex_unlock (&mutex);
+	}
 
 	return filename;
 }
@@ -294,7 +266,7 @@ e_icon_factory_get_icon_filename (const char *icon_name, int icon_size)
 /**
  * e_icon_factory_get_icon:
  * @icon_name: name of the icon
- * @icon_size: size of the icon (one of the E_ICON_SIZE_* enum values)
+ * @icon_size: size of the icon
  *
  * Returns the specified icon of the requested size (may perform
  * scaling to achieve this). If @icon_name is a full path, that file
@@ -305,29 +277,20 @@ e_icon_factory_get_icon_filename (const char *icon_name, int icon_size)
  * requested icon, then a "broken-image" icon is returned.
  **/
 GdkPixbuf *
-e_icon_factory_get_icon (const char *icon_name, int icon_size)
+e_icon_factory_get_icon (const gchar *icon_name,
+                         GtkIconSize icon_size)
 {
 	GdkPixbuf *pixbuf;
 	char *icon_key;
 	Icon *icon;
-	int size;
+	int size, width, height;
 
-	if (icon_size >= E_ICON_NUM_SIZES) {
-		g_warning (
-			"calling %s with unknown icon_size value (%d)",
-			G_STRFUNC, icon_size);
-		if ((icon_size = pixel_size_to_icon_size (icon_size)) == -1)
-			return NULL;
-	}
+	g_return_val_if_fail (icon_name != NULL, NULL);
 
-	size = sizes[icon_size];
+	if (!gtk_icon_size_lookup (icon_size, &width, &height))
+		return NULL;
 
-	if (icon_name == NULL || !strcmp (icon_name, "")) {
-		if (size >= 24)
-			return gdk_pixbuf_scale_simple (broken24_pixbuf, size, size, GDK_INTERP_NEAREST);
-		else
-			return gdk_pixbuf_scale_simple (broken16_pixbuf, size, size, GDK_INTERP_NEAREST);
-	}
+	size = height;
 
 	icon_key = g_alloca (strlen (icon_name) + 7);
 	sprintf (icon_key, "%dx%d/%s", size, size, icon_name);
@@ -353,62 +316,6 @@ e_icon_factory_get_icon (const char *icon_name, int icon_size)
 	return pixbuf;
 }
 
-GtkWidget  *
-e_icon_factory_get_image (const char *icon_name, int icon_size)
-{
-	GdkPixbuf *pixbuf;
-	GtkWidget *image;
-
-	pixbuf = e_icon_factory_get_icon  (icon_name, icon_size);
-	image = gtk_image_new_from_pixbuf (pixbuf);
-	g_object_unref (pixbuf);
-
-	return image;
-}
-
-/**
- * e_icon_factory_get_icon_list:
- * @icon_name: name of the icon
- *
- * Returns a list of GdkPixbufs of the requested name suitable for
- * gtk_window_set_icon_list().
- **/
-GList *
-e_icon_factory_get_icon_list (const char *icon_name)
-{
-	static int icon_list_sizes[] = { 128, 64, 48, 32, 16 };
-	GList *list = NULL;
-	char *icon_key;
-	Icon *icon;
-	int size, i;
-
-	if (!icon_name || !strcmp (icon_name, ""))
-		return NULL;
-
-	g_static_mutex_lock (&mutex);
-
-	icon_key = g_alloca (strlen (icon_name) + 9);
-
-	for (i = 0; i < G_N_ELEMENTS (icon_list_sizes); i++) {
-		size = icon_list_sizes[i];
-		sprintf (icon_key, "%dx%d/%s", size, size, icon_name);
-
-		if (!(icon = g_hash_table_lookup (name_to_icon, icon_key))) {
-			if ((icon = load_icon (icon_key, icon_name, size, FALSE)))
-				g_hash_table_insert (name_to_icon, icon->name, icon);
-		}
-
-		if (icon && icon->pixbuf) {
-			list = g_list_prepend (list, icon->pixbuf);
-			g_object_ref (icon->pixbuf);
-		}
-	}
-
-	g_static_mutex_unlock (&mutex);
-
-	return list;
-}
-
 /**
  * e_icon_factory_pixbuf_scale
  * Scales pixbuf to desired size.
