@@ -1,24 +1,23 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Authors:
- *    Jeffrey Stedfast <fejj@ximian.com>
- *    Dan Winship <danw@ximian.com>
- *
- *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
- *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ *
+ *
+ * Authors:
+ *		Jeffrey Stedfast <fejj@ximian.com>
+ *		Dan Winship <danw@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
@@ -40,6 +39,7 @@ typedef struct _EMAccountEditorClass EMAccountEditorClass;
 typedef enum {
 	EMAE_NOTEBOOK,
 	EMAE_DRUID,
+	EMAE_PAGES
 } em_account_editor_t;
 
 struct _EMAccountEditor {
@@ -55,6 +55,8 @@ struct _EMAccountEditor {
 	struct _EAccount *account; /* working account, must instant apply to this */
 	struct _EAccount *original; /* original account, not changed unless commit is invoked */
 
+	GtkWidget **pages; /* Pages for Anjal's page type editor */
+
 	guint do_signature:1;	/* allow editing signature */
 };
 
@@ -65,6 +67,9 @@ struct _EMAccountEditorClass {
 GType em_account_editor_get_type(void);
 
 EMAccountEditor *em_account_editor_new(struct _EAccount *account, em_account_editor_t type, char *id);
+EMAccountEditor *em_account_editor_new_for_pages(struct _EAccount *account, em_account_editor_t type, char *id, struct _GtkWidget **pages);
+void em_account_editor_commit (EMAccountEditor *emae);
+void em_account_editor_check (EMAccountEditor *emae, const char *page);
 
 gboolean em_account_editor_save (EMAccountEditor *gui);
 void em_account_editor_destroy (EMAccountEditor *gui);
