@@ -79,6 +79,7 @@
 #include "e-util/e-error.h"
 #include "e-util/e-util-private.h"
 #include "e-util/e-util-labels.h"
+#include "e-mail-search-bar.h"
 #include "em-utils.h"
 #include "em-composer-utils.h"
 #include "em-format-html-display.h"
@@ -106,6 +107,7 @@ CamelStore *vfolder_store; /* the 1 static vfolder store */
 struct _EMFolderBrowserPrivate {
 	GtkWidget *preview;	/* container for message display */
 	GtkWidget *scroll;
+	GtkWidget *search_bar;
 
 	GtkWidget *subscribe_editor;
 
@@ -164,7 +166,6 @@ static const EMFolderViewEnable emfb_enable_map[] = {
 	{ "FolderRename", EM_POPUP_SELECT_FOLDER },
 	{ "FolderRefresh", EM_POPUP_SELECT_FOLDER },
 	{ "ChangeFolderProperties", EM_POPUP_SELECT_FOLDER },
-	{ "MailPost", EM_POPUP_SELECT_FOLDER },
 	{ "MessageMarkAllAsRead", EM_POPUP_SELECT_FOLDER },
 	{ "ViewHideSelected", EM_POPUP_SELECT_MANY },
 	{ "ViewThreadsCollapseAll", EM_FOLDER_VIEW_SELECT_THREADED},
@@ -181,7 +182,7 @@ enum {
 static guint folder_browser_signals [LAST_SIGNAL] = {0, };
 
 enum {
-	ESB_SAVE,
+	ESB_SAVE
 };
 
 static ESearchBarItem emfb_search_items[] = {
@@ -240,7 +241,6 @@ static ESearchBarItem emfb_search_scope_items[] = {
 	E_FILTERBAR_CURRENT_FOLDER,
 	E_FILTERBAR_CURRENT_ACCOUNT,
 	E_FILTERBAR_ALL_ACCOUNTS,
-	E_FILTERBAR_CURRENT_MESSAGE,
 	{ NULL, -1, 0 }
 };
 
@@ -486,6 +486,7 @@ emfb_init(GObject *o)
 	EMFolderBrowser *emfb = (EMFolderBrowser *)o;
 	RuleContext *search_context = mail_component_peek_search_context (mail_component_peek ());
 	struct _EMFolderBrowserPrivate *p;
+	GtkWidget *html;
 
 	EMEvent *eme;
 	EMEventTargetFolderBrowser *target;
@@ -528,7 +529,6 @@ emfb_init(GObject *o)
  		efb->account_search_cancel = NULL;
 		e_search_bar_set_menu ((ESearchBar *)emfb->search, emfb_search_items);
 		e_search_bar_set_scopeoption ((ESearchBar *)emfb->search, emfb_search_scope_items);
-		e_search_bar_scope_enable ((ESearchBar *)emfb->search, E_FILTERBAR_CURRENT_MESSAGE_ID, FALSE);
 		emfb->priv->scope_restricted = TRUE;
 		g_signal_connect(emfb, "realize", G_CALLBACK(emfb_realize), NULL);
 		gtk_widget_show((GtkWidget *)emfb->search);
@@ -551,7 +551,7 @@ emfb_init(GObject *o)
 
 	gtk_widget_show(emfb->vpane);
 
-	gtk_box_pack_start_defaults((GtkBox *)emfb, emfb->vpane);
+	gtk_box_pack_start((GtkBox *)emfb, emfb->vpane, TRUE, TRUE, 0);
 
 	gtk_paned_pack1 (GTK_PANED (emfb->vpane), GTK_WIDGET (emfb->view.list), FALSE, FALSE);
 	gtk_widget_show((GtkWidget *)emfb->view.list);
@@ -562,14 +562,21 @@ emfb_init(GObject *o)
 	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)p->scroll, GTK_SHADOW_IN);
 	gtk_widget_show(p->scroll);
 
-	p->preview = gtk_vbox_new (FALSE, 6);
-	gtk_container_add((GtkContainer *)p->scroll, (GtkWidget *)emfb->view.preview->formathtml.html);
-	gtk_widget_show((GtkWidget *)emfb->view.preview->formathtml.html);
+	html = GTK_WIDGET (emfb->view.preview->formathtml.html);
+
+	p->preview = gtk_vbox_new (FALSE, 1);
+	p->search_bar = e_mail_search_bar_new (GTK_HTML (html));
+	gtk_container_add((GtkContainer *)p->scroll, html);
+	gtk_widget_show(html);
 	gtk_box_pack_start ((GtkBox *)p->preview, p->scroll, TRUE, TRUE, 0);
-	gtk_box_pack_start ((GtkBox *)p->preview, em_format_html_get_search_dialog (emfb->view.preview), FALSE, FALSE, 0);
+	gtk_box_pack_start ((GtkBox *)p->preview, p->search_bar, FALSE, FALSE, 0);
 	gtk_paned_pack2 (GTK_PANED (emfb->vpane), p->preview, TRUE, FALSE);
 	gtk_widget_show(p->preview);
 
+	g_signal_connect_swapped (
+		p->search_bar, "changed",
+		G_CALLBACK (em_format_redraw), emfb->view.preview);
+
 	/** @HookPoint-EMFolderBrower: Folder Browser
 	 * @Id: emfb.created
 	 * @Class: org.gnome.evolution.mail.events:1.0
@@ -638,6 +645,14 @@ emfb_destroy(GtkObject *o)
 	((GtkObjectClass *)emfb_parent)->destroy(o);
 }
 
+static void
+emfb_show_search_bar (EMFolderView *folder_view)
+{
+	EMFolderBrowser *browser = (EMFolderBrowser *) folder_view;
+
+	gtk_widget_show (browser->priv->search_bar);
+}
+
 static void
 emfb_class_init(GObjectClass *klass)
 {
@@ -667,6 +682,7 @@ emfb_class_init(GObjectClass *klass)
 	((GtkObjectClass *)klass)->destroy = emfb_destroy;
 	((EMFolderViewClass *)klass)->set_folder = emfb_set_folder;
 	((EMFolderViewClass *)klass)->activate = emfb_activate;
+	((EMFolderViewClass *)klass)->show_search_bar = emfb_show_search_bar;
 }
 
 GType
@@ -712,7 +728,6 @@ void em_folder_browser_show_preview(EMFolderBrowser *emfb, gboolean state)
 	if ((emfb->view.preview_active ^ state) == 0
 	    || emfb->view.list == NULL) {
 		if (state && emfb->priv->scope_restricted && emfb->view.list->cursor_uid && *(emfb->view.list->cursor_uid)) {
-			e_search_bar_scope_enable ((ESearchBar *)emfb->search, E_FILTERBAR_CURRENT_MESSAGE_ID, TRUE);
 			emfb->priv->scope_restricted = FALSE;
 		}
 
@@ -734,7 +749,6 @@ void em_folder_browser_show_preview(EMFolderBrowser *emfb, gboolean state)
 		if (emfb->view.list->cursor_uid) {
 			char *uid = g_alloca(strlen(emfb->view.list->cursor_uid)+1);
 
-			e_search_bar_scope_enable ((ESearchBar *)emfb->search, E_FILTERBAR_CURRENT_MESSAGE_ID, TRUE);
 			emfb->priv->scope_restricted = FALSE;
 			strcpy(uid, emfb->view.list->cursor_uid);
 			em_folder_view_set_message(&emfb->view, uid, FALSE);
@@ -750,7 +764,6 @@ void em_folder_browser_show_preview(EMFolderBrowser *emfb, gboolean state)
 		emfb->view.displayed_uid = NULL;
 
 		gtk_widget_hide(emfb->priv->preview);
-		e_search_bar_scope_enable ((ESearchBar *)emfb->search, E_FILTERBAR_CURRENT_MESSAGE_ID, FALSE);
 		emfb->priv->scope_restricted = TRUE;
 		/*
 		mail_display_set_message (emfb->mail_display, NULL, NULL, NULL);
@@ -784,7 +797,7 @@ void em_folder_browser_show_wide(EMFolderBrowser *emfb, gboolean state)
 	g_signal_connect(w, "realize", G_CALLBACK(emfb_pane_realised), emfb);
 	emfb->priv->vpane_resize_id = g_signal_connect(w, "button_release_event", G_CALLBACK(emfb_pane_button_release_event), emfb);
 
-	gtk_box_pack_start_defaults((GtkBox *)emfb, w);
+	gtk_box_pack_start((GtkBox *)emfb, w, TRUE, TRUE, 0);
 	gtk_widget_reparent((GtkWidget *)emfb->view.list, w);
 	gtk_widget_reparent((GtkWidget *)emfb->priv->preview, w);
 	gtk_widget_destroy(emfb->vpane);
@@ -842,6 +855,8 @@ static void
 emfb_search_config_search(EFilterBar *efb, FilterRule *rule, int id, const char *query, void *data)
 {
 	EMFolderBrowser *emfb = data;
+	EMailSearchBar *search_bar;
+	ESearchingTokenizer *tokenizer;
 	GList *partl;
 	struct _camel_search_words *words;
 	int i;
@@ -878,15 +893,26 @@ emfb_search_config_search(EFilterBar *efb, FilterRule *rule, int id, const char
 		partl = partl->next;
 	}
 
-	em_format_html_display_set_search(emfb->view.preview,
-					  EM_FORMAT_HTML_DISPLAY_SEARCH_SECONDARY|EM_FORMAT_HTML_DISPLAY_SEARCH_ICASE,
-					  strings);
-	while (strings) {
-		GSList *n = strings->next;
-		g_free(strings->data);
-		g_slist_free_1(strings);
-		strings = n;
+	search_bar = E_MAIL_SEARCH_BAR (emfb->priv->search_bar);
+
+	/* XXX This is a hack, but this code is on its way out anyway.
+	 *     Function is called once before the search bar is created. */
+	if (!E_IS_MAIL_SEARCH_BAR (search_bar))
+		return;
+
+	tokenizer = e_mail_search_bar_get_tokenizer (search_bar);
+
+	e_searching_tokenizer_set_secondary_case_sensitivity (tokenizer, FALSE);
+	e_searching_tokenizer_set_secondary_search_string (tokenizer, NULL);
+
+	while (strings != NULL) {
+		e_searching_tokenizer_add_secondary_search_string (
+			tokenizer, strings->data);
+		g_free (strings->data);
+		strings = g_slist_delete_link (strings, strings);
 	}
+
+	e_mail_search_bar_changed (search_bar);
 }
 
 static char *
@@ -1126,18 +1152,6 @@ emfb_search_search_activated(ESearchBar *esb, EMFolderBrowser *emfb)
 	id = e_search_bar_get_search_scope (esb);
 
 	switch (id) {
-	    case E_FILTERBAR_CURRENT_MESSAGE_ID:
-		    word = e_search_bar_get_text (esb);
-		    if ( word && *word ) {
-			    gtk_widget_set_sensitive (esb->option_button, FALSE);
-			    em_format_html_display_search_with (emfb->view.preview, word);
-		    } else {
-			    em_format_html_display_search_close (emfb->view.preview);
-		    }
-		    g_free (word);
-		    return;
-		    break;
-
 	    case E_FILTERBAR_CURRENT_FOLDER_ID:
 		    g_object_get (esb, "query", &search_word, NULL);
 		    break;
@@ -1363,7 +1377,7 @@ emfb_list_key_press(ETree *tree, int row, ETreePath path, int col, GdkEvent *ev,
 	}
 
 	if (!folder_choose && !emfb->view.preview->caret_mode && mail_config_get_enable_magic_spacebar ()) {
-		//check for unread messages. if yes .. rewindback to the folder
+		/* check for unread messages. if yes .. rewindback to the folder */
 		EMFolderTree *emft = g_object_get_data((GObject*)emfb, "foldertree");
 		switch (ev->key.keyval) {
 		    case GDK_space:
@@ -1387,10 +1401,8 @@ emfb_list_message_selected (MessageList *ml, const char *uid, EMFolderBrowser *e
 		return;
 
 	if (uid && *uid && emfb->priv->scope_restricted && emfb->view.preview_active) {
-		e_search_bar_scope_enable ((ESearchBar *)emfb->search, E_FILTERBAR_CURRENT_MESSAGE_ID, TRUE);
 		emfb->priv->scope_restricted = FALSE;
 	} else if ( !(uid && *uid) && !emfb->priv->scope_restricted) {
-		e_search_bar_scope_enable ((ESearchBar *)emfb->search, E_FILTERBAR_CURRENT_MESSAGE_ID, FALSE);
 		emfb->priv->scope_restricted = TRUE;
 	}
 
@@ -1612,11 +1624,11 @@ emfb_folder_create(BonoboUIComponent *uid, void *data, const char *path)
 	   FIXME: This interface should NOT use a folderinfo */
 	if (emfb->view.folder) {
 		if ((fi = em_folder_tree_get_selected_folder_info (tree)) != NULL) {
-			em_folder_utils_create_folder(fi, tree);
+			em_folder_utils_create_folder (fi, tree, NULL);
 			camel_folder_info_free(fi);
 		}
 	} else {
-		em_folder_utils_create_folder(NULL, tree);
+		em_folder_utils_create_folder (NULL, tree, NULL);
 	}
 
 	return;
@@ -1693,13 +1705,6 @@ emfb_mail_stop(BonoboUIComponent *uid, void *data, const char *path)
 	mail_cancel_all();
 }
 
-static void
-emfb_mail_post(BonoboUIComponent *uid, void *data, const char *path)
-{
-	EMFolderView *emfv = data;
-	em_utils_post_to_folder (emfv->folder);
-}
-
 static void
 emfb_tools_filters(BonoboUIComponent *uid, void *data, const char *path)
 {
@@ -1779,7 +1784,6 @@ static BonoboUIVerb emfb_verbs[] = {
 	BONOBO_UI_UNSAFE_VERB ("FolderCreate", emfb_folder_create),
 	BONOBO_UI_UNSAFE_VERB ("HelpDebug", emfb_help_debug),
 
-	BONOBO_UI_UNSAFE_VERB ("MailPost", emfb_mail_post),
 	BONOBO_UI_UNSAFE_VERB ("MailStop", emfb_mail_stop),
 	BONOBO_UI_UNSAFE_VERB ("ToolsFilters", emfb_tools_filters),
 	BONOBO_UI_UNSAFE_VERB ("ToolsSubscriptions", emfb_tools_subscriptions),
@@ -1792,11 +1796,11 @@ static BonoboUIVerb emfb_verbs[] = {
 };
 
 static EPixmap emfb_pixmaps[] = {
-	E_PIXMAP ("/commands/FolderCreate", "folder-new", E_ICON_SIZE_MENU),
-	E_PIXMAP ("/commands/ChangeFolderProperties", "document-properties", E_ICON_SIZE_MENU),
-	E_PIXMAP ("/commands/FolderCopy", "folder-copy", E_ICON_SIZE_MENU),
-	E_PIXMAP ("/commands/FolderMove", "folder-move", E_ICON_SIZE_MENU),
-	E_PIXMAP ("/commands/MessageMarkAllAsRead", "mail-read", E_ICON_SIZE_MENU),
+	E_PIXMAP ("/commands/FolderCreate", "folder-new", GTK_ICON_SIZE_MENU),
+	E_PIXMAP ("/commands/ChangeFolderProperties", "document-properties", GTK_ICON_SIZE_MENU),
+	E_PIXMAP ("/commands/FolderCopy", "folder-copy", GTK_ICON_SIZE_MENU),
+	E_PIXMAP ("/commands/FolderMove", "folder-move", GTK_ICON_SIZE_MENU),
+	E_PIXMAP ("/commands/MessageMarkAllAsRead", "mail-read", GTK_ICON_SIZE_MENU),
 
 	E_PIXMAP_END
 };
