@@ -1,22 +1,22 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Authors: Jeffrey Stedfast <fejj@ximian.com>
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
- *  Copyright 2002-2003 Ximian, Inc. (www.ximian.com)
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * Authors:
+ *		Jeffrey Stedfast <fejj@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
@@ -51,7 +51,7 @@
 
 static void em_mailer_prefs_class_init (EMMailerPrefsClass *class);
 static void em_mailer_prefs_init       (EMMailerPrefs *dialog);
-static void em_mailer_prefs_finalise   (GObject *obj);
+static void em_mailer_prefs_dispose    (GObject *obj);
 
 static GtkVBoxClass *parent_class = NULL;
 
@@ -60,7 +60,7 @@ enum {
 	HEADER_LIST_ENABLED_COLUMN, /* is the header enabled? */
 	HEADER_LIST_IS_DEFAULT_COLUMN,  /* is this header a default header, eg From: */
 	HEADER_LIST_HEADER_COLUMN, /* the real name of this header */
-	HEADER_LIST_N_COLUMNS,
+	HEADER_LIST_N_COLUMNS
 };
 
 static GType col_types[] = {
@@ -80,6 +80,7 @@ static const char *default_headers[] = {
 	N_("Subject"),
 	N_("Date"),
 	N_("Newsgroups"),
+	N_("Face"),
 	"x-evolution-mailer", /* DO NOT translate */
 };
 
@@ -126,7 +127,7 @@ em_mailer_prefs_class_init (EMMailerPrefsClass *klass)
 	object_class = (GObjectClass *) klass;
 	parent_class = g_type_class_ref (gtk_vbox_get_type ());
 
-	object_class->finalize = em_mailer_prefs_finalise;
+	object_class->dispose = em_mailer_prefs_dispose;
 }
 
 static void
@@ -136,10 +137,15 @@ em_mailer_prefs_init (EMMailerPrefs *preferences)
 }
 
 static void
-em_mailer_prefs_finalise (GObject *obj)
+em_mailer_prefs_dispose (GObject *obj)
 {
 	EMMailerPrefs *prefs = (EMMailerPrefs *) obj;
 
+	if (prefs->header_list_store) {
+		g_object_unref (prefs->header_list_store);
+		prefs->header_list_store = NULL;
+	}
+
 	g_object_unref (prefs->gui);
 
 	if (prefs->labels_change_notify_id) {
@@ -148,7 +154,7 @@ em_mailer_prefs_finalise (GObject *obj)
 		prefs->labels_change_notify_id = 0;
 	}
 
-        ((GObjectClass *)(parent_class))->finalize (obj);
+        ((GObjectClass *)(parent_class))->dispose (obj);
 }
 
 
@@ -184,7 +190,7 @@ enum {
 
 enum {
 	JH_LIST_COLUMN_NAME,
-	JH_LIST_COLUMN_VALUE,
+	JH_LIST_COLUMN_VALUE
 };
 static void
 label_sensitive_buttons (EMMailerPrefs *prefs)
@@ -295,9 +301,10 @@ label_tree_refill (GConfClient *client, guint cnxn_id, GConfEntry *entry, gpoint
 static void
 jh_tree_refill (EMMailerPrefs *prefs)
 {
-	GtkListStore *store = prefs->junk_header_list_store;
+	GtkListStore *store;
 	GSList *l, *cjh = gconf_client_get_list (prefs->gconf, "/apps/evolution/mail/junk/custom_header", GCONF_VALUE_STRING, NULL);
 
+	store = GTK_LIST_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (prefs->junk_header_tree)));
 	gtk_list_store_clear (store);
 
 	for (l = cjh; l; l = l->next) {
@@ -349,7 +356,7 @@ jh_add_cb (GtkWidget *widget, gpointer user_data)
 		char *tok;
 		GSList *list = gconf_client_get_list (prefs->gconf, "/apps/evolution/mail/junk/custom_header", GCONF_VALUE_STRING, NULL);
 		
-		//FIXME: Validate the values
+		/* FIXME: Validate the values */
 		
 		tok = g_strdup_printf ("%s=%s", name, value);
 		list = g_slist_append (list, tok);
@@ -415,44 +422,46 @@ jh_remove_cb (GtkWidget *widget, gpointer user_data)
 }
 
 
-static GtkListStore *
-init_junk_tree (GtkWidget *label_tree, EMMailerPrefs *prefs)
+static gboolean
+init_junk_tree (GtkTreeView *jh_tree, EMMailerPrefs *prefs)
 {
 	GtkListStore *store;
 	GtkCellRenderer *renderer;
 	gint col;
 
-	g_return_val_if_fail (label_tree != NULL, NULL);
-	g_return_val_if_fail (prefs != NULL, NULL);
+	g_return_val_if_fail (jh_tree != NULL, FALSE);
+	g_return_val_if_fail (prefs != NULL, FALSE);
 
 	store = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_STRING);
-	gtk_tree_view_set_model (GTK_TREE_VIEW (label_tree), GTK_TREE_MODEL (store));
+	gtk_tree_view_set_model (GTK_TREE_VIEW (jh_tree), GTK_TREE_MODEL (store));
+ 	g_object_unref (store);
 
 	renderer = gtk_cell_renderer_text_new ();
-	col = gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (label_tree), -1, _("Header"), renderer, "text", JH_LIST_COLUMN_NAME, NULL);
+	col = gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (jh_tree), -1, _("Header"), renderer, "text", JH_LIST_COLUMN_NAME, NULL);
 	g_object_set (G_OBJECT (renderer), "editable", TRUE, NULL);
 
 	renderer = gtk_cell_renderer_text_new ();
-	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (label_tree), -1, _("Contains Value"), renderer, "text", JH_LIST_COLUMN_VALUE, NULL);
+	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (jh_tree), -1, _("Contains Value"), renderer, "text", JH_LIST_COLUMN_VALUE, NULL);
 	g_object_set (G_OBJECT (renderer), "editable", TRUE, NULL);
 
-	label_tree_refill (NULL, 0, NULL, prefs);
+	jh_tree_refill (prefs);
 
-	return store;
+ 	return TRUE;
 }
 
-static GtkListStore *
+static gboolean
 init_label_tree (GtkWidget *label_tree, EMMailerPrefs *prefs, gboolean locked)
 {
 	GtkListStore *store;
 	GtkCellRenderer *renderer;
 	gint col;
 
-	g_return_val_if_fail (label_tree != NULL, NULL);
-	g_return_val_if_fail (prefs != NULL, NULL);
+	g_return_val_if_fail (label_tree != NULL, FALSE);
+	g_return_val_if_fail (prefs != NULL, FALSE);
 
 	store = gtk_list_store_new (3, GDK_TYPE_COLOR, G_TYPE_STRING, G_TYPE_STRING);
 	gtk_tree_view_set_model (GTK_TREE_VIEW (label_tree), GTK_TREE_MODEL (store));
+ 	g_object_unref (store);
 
 	renderer = e_cell_renderer_color_new ();
 	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (label_tree), -1, _("Color"), renderer, "color", LABEL_LIST_COLUMN_COLOR, NULL);
@@ -473,7 +482,7 @@ init_label_tree (GtkWidget *label_tree, EMMailerPrefs *prefs, gboolean locked)
 
 	prefs->labels_change_notify_id = gconf_client_notify_add (prefs->gconf, E_UTIL_LABELS_GCONF_KEY, label_tree_refill, prefs, NULL, NULL);
 
-	return store;
+	return TRUE;
 }
 
 static void
@@ -833,18 +842,6 @@ custom_junk_button_toggled (GtkToggleButton *toggle, EMMailerPrefs *prefs)
 
 }
 
-#if 0
-// not used at the moment, commenting out
-static void
-toggle_button_toggled_not (GtkToggleButton *toggle, EMMailerPrefs *prefs)
-{
-	const char *key;
-
-	key = g_object_get_data ((GObject *) toggle, "key");
-	gconf_client_set_bool (prefs->gconf, key, !gtk_toggle_button_get_active (toggle), NULL);
-}
-#endif
-
 static void
 custom_font_changed (GtkToggleButton *toggle, EMMailerPrefs *prefs)
 {
@@ -924,82 +921,74 @@ charset_menu_init (EMMailerPrefs *prefs)
 }
 
 static void
-trash_days_activate (GtkWidget *item, EMMailerPrefs *prefs)
+trash_days_changed (GtkComboBox *combobox, EMMailerPrefs *prefs)
 {
-	int days;
+	int idx;
 
-	days = GPOINTER_TO_INT (g_object_get_data ((GObject *) item, "days"));
-	gconf_client_set_int (prefs->gconf, "/apps/evolution/mail/trash/empty_on_exit_days", days, NULL);
+	idx = gtk_combo_box_get_active (combobox);
+	g_return_if_fail (idx >= 0 && idx < G_N_ELEMENTS (empty_trash_frequency));
+
+	gconf_client_set_int (prefs->gconf, "/apps/evolution/mail/trash/empty_on_exit_days", empty_trash_frequency [idx].days, NULL);
 }
 
 static void
 emmp_empty_trash_init (EMMailerPrefs *prefs)
 {
 	int locked, days, hist = 0, i;
-	GtkWidget *menu, *item;
 
 	toggle_button_init (prefs, prefs->empty_trash, FALSE,
 			    "/apps/evolution/mail/trash/empty_on_exit",
 			    G_CALLBACK (toggle_button_toggled));
 
 	days = gconf_client_get_int(prefs->gconf, "/apps/evolution/mail/trash/empty_on_exit_days", NULL);
-	menu = gtk_menu_new();
+
+	gtk_list_store_clear (GTK_LIST_STORE (gtk_combo_box_get_model (prefs->empty_trash_days)));
 	for (i = 0; i < G_N_ELEMENTS (empty_trash_frequency); i++) {
 		if (days >= empty_trash_frequency[i].days)
 			hist = i;
 
-		item = gtk_menu_item_new_with_label (_(empty_trash_frequency[i].label));
-		g_object_set_data ((GObject *) item, "days", GINT_TO_POINTER (empty_trash_frequency[i].days));
-		g_signal_connect (item, "activate", G_CALLBACK (trash_days_activate), prefs);
-
-		gtk_widget_show (item);
-		gtk_menu_shell_append((GtkMenuShell *)menu, item);
+		gtk_combo_box_append_text  (prefs->empty_trash_days, _(empty_trash_frequency[i].label));
 	}
 
-	gtk_widget_show(menu);
-	gtk_option_menu_set_menu((GtkOptionMenu *)prefs->empty_trash_days, menu);
-	gtk_option_menu_set_history((GtkOptionMenu *)prefs->empty_trash_days, hist);
+	g_signal_connect (prefs->empty_trash_days, "changed", G_CALLBACK (trash_days_changed), prefs);
+	gtk_combo_box_set_active (prefs->empty_trash_days, hist);
 
 	locked = !gconf_client_key_is_writable (prefs->gconf, "/apps/evolution/mail/trash/empty_on_exit_days", NULL);
 	gtk_widget_set_sensitive ((GtkWidget *) prefs->empty_trash_days, !locked);
 }
 
 static void
-junk_days_activate (GtkWidget *item, EMMailerPrefs *prefs)
+junk_days_changed (GtkComboBox *combobox, EMMailerPrefs *prefs)
 {
-	int days;
+	int idx;
 
-	days = GPOINTER_TO_INT (g_object_get_data ((GObject *) item, "days"));
-	gconf_client_set_int (prefs->gconf, "/apps/evolution/mail/junk/empty_on_exit_days", days, NULL);
+	idx = gtk_combo_box_get_active (combobox);
+	g_return_if_fail (idx >= 0 && idx < G_N_ELEMENTS (empty_trash_frequency));
+
+	gconf_client_set_int (prefs->gconf, "/apps/evolution/mail/junk/empty_on_exit_days", empty_trash_frequency[idx].days, NULL);
 }
 
 static void
 emmp_empty_junk_init (EMMailerPrefs *prefs)
 {
 	int locked, days, hist = 0, i;
-	GtkWidget *menu, *item;
 
 	toggle_button_init (prefs, prefs->empty_junk, FALSE,
 			    "/apps/evolution/mail/junk/empty_on_exit",
 			    G_CALLBACK (toggle_button_toggled));
 
 	days = gconf_client_get_int(prefs->gconf, "/apps/evolution/mail/junk/empty_on_exit_days", NULL);
-	menu = gtk_menu_new();
+
+	gtk_list_store_clear (GTK_LIST_STORE (gtk_combo_box_get_model (prefs->empty_junk_days)));
 	for (i = 0; i < G_N_ELEMENTS (empty_trash_frequency); i++) {
 		if (days >= empty_trash_frequency[i].days)
 			hist = i;
 
-		item = gtk_menu_item_new_with_label (_(empty_trash_frequency[i].label));
-		g_object_set_data ((GObject *) item, "days", GINT_TO_POINTER (empty_trash_frequency[i].days));
-		g_signal_connect (item, "activate", G_CALLBACK (junk_days_activate), prefs);
-
-		gtk_widget_show (item);
-		gtk_menu_shell_append((GtkMenuShell *)menu, item);
+		gtk_combo_box_append_text  (prefs->empty_junk_days, _(empty_trash_frequency[i].label));
 	}
 
-	gtk_widget_show(menu);
-	gtk_option_menu_set_menu((GtkOptionMenu *)prefs->empty_junk_days, menu);
-	gtk_option_menu_set_history((GtkOptionMenu *)prefs->empty_junk_days, hist);
+	g_signal_connect (prefs->empty_junk_days, "changed", G_CALLBACK (junk_days_changed), prefs);
+	gtk_combo_box_set_active (prefs->empty_junk_days, hist);
 
 	locked = !gconf_client_key_is_writable (prefs->gconf, "/apps/evolution/mail/junk/empty_on_exit_days", NULL);
 	gtk_widget_set_sensitive ((GtkWidget *) prefs->empty_junk_days, !locked);
@@ -1259,7 +1248,7 @@ em_mailer_prefs_construct (EMMailerPrefs *prefs)
 
 	/* Deleting Mail */
 	prefs->empty_trash = GTK_TOGGLE_BUTTON (glade_xml_get_widget (gui, "chkEmptyTrashOnExit"));
-	prefs->empty_trash_days = GTK_OPTION_MENU (glade_xml_get_widget (gui, "omenuEmptyTrashDays"));
+	prefs->empty_trash_days = GTK_COMBO_BOX (glade_xml_get_widget (gui, "comboboxEmptyTrashDays"));
 	emmp_empty_trash_init (prefs);
 
 	prefs->confirm_expunge = GTK_TOGGLE_BUTTON (glade_xml_get_widget (gui, "chkConfirmExpunge"));
@@ -1339,7 +1328,7 @@ em_mailer_prefs_construct (EMMailerPrefs *prefs)
 	gtk_widget_set_sensitive (prefs->label_edit, !locked);
 	gtk_widget_set_sensitive (prefs->label_tree, !locked);
 
-	prefs->label_list_store = init_label_tree (prefs->label_tree, prefs, locked);
+	init_label_tree (prefs->label_tree, prefs, locked);
 
 	if (!locked) {
 		g_signal_connect (G_OBJECT (prefs->label_add), "clicked", G_CALLBACK (label_add_cb), prefs);
@@ -1472,7 +1461,7 @@ em_mailer_prefs_construct (EMMailerPrefs *prefs)
 			    G_CALLBACK (toggle_button_toggled));
 
 	prefs->empty_junk = GTK_TOGGLE_BUTTON (glade_xml_get_widget (gui, "junk_empty_check"));
-	prefs->empty_junk_days = GTK_OPTION_MENU (glade_xml_get_widget (gui, "junk_empty_combo"));
+	prefs->empty_junk_days = GTK_COMBO_BOX (glade_xml_get_widget (gui, "junk_empty_combobox"));
 	emmp_empty_junk_init (prefs);
 
 	prefs->default_junk_plugin = GTK_COMBO_BOX (glade_xml_get_widget (gui, "default_junk_plugin"));
@@ -1496,7 +1485,7 @@ em_mailer_prefs_construct (EMMailerPrefs *prefs)
 
 	junk_book_lookup_button_toggled (prefs->junk_book_lookup, prefs);
 
-	prefs->junk_header_list_store = init_junk_tree ((GtkWidget *)prefs->junk_header_tree, prefs);
+	init_junk_tree ((GtkTreeView *)prefs->junk_header_tree, prefs);
 	toggle_button_init (prefs, prefs->junk_header_check, FALSE,
 			    "/apps/evolution/mail/junk/check_custom_header",
 			    G_CALLBACK (custom_junk_button_toggled));
