@@ -104,7 +104,7 @@ enum _em_popup_target_select_t {
 	EM_POPUP_SELECT_FOLDER             = 1<<15,     /* do we have any folder at all? */
 	EM_POPUP_SELECT_JUNK               = 1<<16,
 	EM_POPUP_SELECT_NOT_JUNK           = 1<<17,
-	EM_POPUP_SELECT_LAST               = 1<<18,
+	EM_POPUP_SELECT_LAST               = 1<<18
 };
 
 /**
@@ -113,14 +113,12 @@ enum _em_popup_target_select_t {
  * @EM_POPUP_URI_HTTP: This is a HTTP or HTTPS url.
  * @EM_POPUP_URI_MAILTO: This is a MAILTO url.
  * @EM_POPUP_URI_NOT_MAILTO: This is not a MAILTO url.
- * @EM_POPUP_URI_CALLTO: This is a CALLTO url.
  *
  **/
 enum _em_popup_target_uri_t {
 	EM_POPUP_URI_HTTP = 1<<0,
 	EM_POPUP_URI_MAILTO = 1<<1,
-	EM_POPUP_URI_NOT_MAILTO = 1<<2,
-	EM_POPUP_URI_CALLTO = 1<<3,
+	EM_POPUP_URI_NOT_MAILTO = 1<<2
 };
 
 /**
@@ -132,7 +130,7 @@ enum _em_popup_target_uri_t {
  **/
 enum _em_popup_target_part_t {
 	EM_POPUP_PART_MESSAGE = 1<<0,
-	EM_POPUP_PART_IMAGE = 1<<1,
+	EM_POPUP_PART_IMAGE = 1<<1
 };
 
 /**
@@ -153,7 +151,7 @@ enum _em_popup_target_folder_t {
 	EM_POPUP_FOLDER_DELETE = 1<<3, /* folder can be deleted/renamed */
 	EM_POPUP_FOLDER_SELECT = 1<<4, /* folder can be selected/opened */
 	EM_POPUP_FOLDER_OUTBOX = 1<<5, /* Outbox folder */
-	EM_POPUP_FOLDER_NONSTATIC = 1<<6, /* Except static folders like Outbox.*/
+	EM_POPUP_FOLDER_NONSTATIC = 1<<6 /* Except static folders like Outbox.*/
 };
 
 typedef struct _EMPopupTargetSelect EMPopupTargetSelect;
