@@ -1,23 +1,24 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Copyright(C)2000-2002 Ximian Inc.
- *
- *  Author: Not Zed <notzed@lostzed.mmc.com.au>
- *          Jeffrey Stedfast <fejj@ximian.com>
- *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ *
+ *
+ * Authors:
+ *		Not Zed <notzed@lostzed.mmc.com.au>
+ *      Jeffrey Stedfast <fejj@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -365,7 +366,7 @@ rule_copy(FilterRule *dest, FilterRule *src)
 enum {
 	BUTTON_ADD,
 	BUTTON_REMOVE,
-	BUTTON_LAST,
+	BUTTON_LAST
 };
 
 struct _source_data {
@@ -383,7 +384,7 @@ static void source_remove(GtkWidget *widget, struct _source_data *data);
 
 static struct {
 	char *name;
-	GtkSignalFunc func;
+	GCallback func;
 } edit_buttons[] = {
 	{ "source_add",    G_CALLBACK(source_add)   },
 	{ "source_remove", G_CALLBACK(source_remove)},
@@ -673,7 +674,7 @@ get_widget(FilterRule *fr, RuleContext *rc)
 
 	rb = g_slist_nth_data(gtk_radio_button_get_group (rb), vr->with);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (rb), TRUE);
-	gtk_signal_emit_by_name (GTK_OBJECT (rb), "toggled");
+	g_signal_emit_by_name (rb, "toggled");
 
 	set_sensitive(data);
 
