@@ -1,22 +1,22 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
- *
- * Authors: Michael Zucchi <notzed@ximian.com>
- *
- * Copyright 2000, Ximian, Inc. (www.ximian.com)
- *
+/*
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ *
+ *
+ * Authors:
+ *		Michael Zucchi <notzed@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
@@ -100,7 +100,7 @@ typedef struct _MailAsyncEvent {
 
 typedef enum _mail_async_event_t {
 	MAIL_ASYNC_GUI,
-	MAIL_ASYNC_THREAD,
+	MAIL_ASYNC_THREAD
 } mail_async_event_t;
 
 typedef void (*MailAsyncFunc)(void *, void *, void *);
@@ -119,7 +119,7 @@ typedef enum {
 	MAIL_CALL_p_ppp,
 	MAIL_CALL_p_pppp,
 	MAIL_CALL_p_ppppp,
-	MAIL_CALL_p_ppippp,
+	MAIL_CALL_p_ppippp
 } mail_call_t;
 
 typedef void *(*MailMainFunc)();
