@@ -1,25 +1,24 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-
 /*
- * Authors:
- *  Peter Williams <peterw@ximian.com>
- *  Michael Zucchi <notzed@ximian.com>
- *
- * Copyright 2000, 2001 Ximian, Inc. (www.ximian.com)
- *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ *
+ *
+ * Authors:
+ *		Peter Williams <peterw@ximian.com>
+ *		Michael Zucchi <notzed@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
- * USA
  */
 
 #ifndef MAIL_OPS_H
@@ -58,7 +57,7 @@ void mail_get_message (CamelFolder *folder, const char *uid,
 		       void *data,
 		       MailMsgDispatchFunc dispatch);
 
-void
+CamelOperation *
 mail_get_messagex(CamelFolder *folder, const char *uid,
 		  void (*done) (CamelFolder *folder, const char *uid, CamelMimeMessage *msg, void *data, CamelException *),
 		  void *data, MailMsgDispatchFunc dispatch);
@@ -112,8 +111,8 @@ int mail_get_folderinfo (CamelStore *store, CamelOperation *op,
 			 void *data);
 
 /* remove an existing folder */
-void mail_remove_folder (const char *uri,
-			 void (*done) (char *uri, gboolean removed, void *data),
+void mail_remove_folder (CamelFolder *folder,
+			 void (*done) (CamelFolder *folder, gboolean removed, CamelException *ex, void *data),
 			 void *data);
 
 /* transfer (copy/move) a folder */
