@@ -105,7 +105,7 @@ struct _send_info {
 	send_info_t type;		/* 0 = fetch, 1 = send */
 	CamelOperation *cancel;
 	char *uri;
-	int keep;
+	gboolean keep_on_server;
 	send_state_t state;
 	GtkWidget *progress_bar;
 	GtkWidget *cancel_button;
@@ -415,6 +415,11 @@ build_dialog (EAccountList *accounts, CamelFolder *outbox, const char *destinati
 
 	g_object_unref (iter);
 
+	/* Check to see if we have to send any mails --- if we don't, don't display the SMTP row in the table */
+	if (outbox && destination 
+	 && (camel_folder_get_message_count(outbox) - camel_folder_get_deleted_message_count(outbox)) == 0)
+		num_sources--;
+
 	table = gtk_table_new (num_sources, 4, FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (table), 6);
 	gtk_table_set_row_spacings (GTK_TABLE (table), 6);
@@ -466,7 +471,7 @@ build_dialog (EAccountList *accounts, CamelFolder *outbox, const char *destinati
 			d(printf("adding source %s\n", source->url));
 
 			info->uri = g_strdup (source->url);
-			info->keep = source->keep_on_server;
+			info->keep_on_server = source->keep_on_server;
 			info->cancel = camel_operation_new (operation_status, info);
 			info->state = SEND_ACTIVE;
 			info->timeout_id = g_timeout_add (STATUS_TIMEOUT, operation_status_timeout, info);
@@ -539,7 +544,9 @@ build_dialog (EAccountList *accounts, CamelFolder *outbox, const char *destinati
 	target = em_event_target_new_send_receive (em_event_peek(), table, data, row, EM_EVENT_SEND_RECEIVE);
 	e_event_emit ((EEvent *)em_event_peek (), "mail.sendreceive", (EEventTarget *) target);
 
-	if (outbox && destination) {
+	/* Skip displaying the SMTP row if we've got no outbox, destination or unsent mails */
+	if (outbox && destination 
+	 && (camel_folder_get_message_count(outbox) - camel_folder_get_deleted_message_count(outbox)) != 0) {
 		info = g_hash_table_lookup (data->active, SEND_URI_KEY);
 		if (info == NULL) {
 			info = g_malloc0 (sizeof (*info));
@@ -547,7 +554,7 @@ build_dialog (EAccountList *accounts, CamelFolder *outbox, const char *destinati
 			d(printf("adding dest %s\n", destination));
 
 			info->uri = g_strdup (destination);
-			info->keep = FALSE;
+			info->keep_on_server = FALSE;
 			info->cancel = camel_operation_new (operation_status, info);
 			info->state = SEND_ACTIVE;
 			info->timeout_id = g_timeout_add (STATUS_TIMEOUT, operation_status_timeout, info);
@@ -601,9 +608,9 @@ build_dialog (EAccountList *accounts, CamelFolder *outbox, const char *destinati
 		g_signal_connect (
 			cancel_button, "clicked",
 			G_CALLBACK (receive_cancel), info);
-		gtk_widget_show_all (table);
 	}
 
+	gtk_widget_show_all (table);
 	gtk_widget_show (GTK_WIDGET (gd));
 
 	g_signal_connect (gd, "response", G_CALLBACK (dialog_response), data);
@@ -925,7 +932,7 @@ mail_send_receive (void)
 
 		switch(info->type) {
 		case SEND_RECEIVE:
-			mail_fetch_mail(info->uri, info->keep,
+			mail_fetch_mail(info->uri, info->keep_on_server,
 					FILTER_SOURCE_INCOMING,
 					info->cancel,
 					receive_get_folder, info,
@@ -966,11 +973,15 @@ auto_timeout(void *data)
 {
 	struct _auto_data *info = data;
 
-	if (camel_session_is_online(session)) {
-		const char *uri = e_account_get_string(info->account, E_ACCOUNT_SOURCE_URL);
-		int keep = e_account_get_bool(info->account, E_ACCOUNT_SOURCE_KEEP_ON_SERVER);
+	if (camel_session_is_online (session)) {
+		const gchar *uri;
+		gboolean keep_on_server;
 
-		mail_receive_uri(uri, keep);
+		uri = e_account_get_string (
+			info->account, E_ACCOUNT_SOURCE_URL);
+		keep_on_server = e_account_get_bool (
+			info->account, E_ACCOUNT_SOURCE_KEEP_ON_SERVER);
+		mail_receive_uri (uri, keep_on_server);
 	}
 
 	return TRUE;
@@ -1016,7 +1027,7 @@ auto_account_commit(struct _auto_data *info)
 	}
 	info->period = period;
 	if (check && info->timeout_id == 0)
-		info->timeout_id = g_timeout_add(info->period*1000, auto_timeout, info);
+		info->timeout_id = g_timeout_add_seconds(info->period, auto_timeout, info);
 }
 
 static void
@@ -1085,7 +1096,7 @@ mail_autoreceive_init (CamelSession *session)
 /* we setup the download info's in a hashtable, if we later need to build the gui, we insert
    them in to add them. */
 void
-mail_receive_uri (const char *uri, int keep)
+mail_receive_uri (const gchar *uri, gboolean keep_on_server)
 {
 	struct _send_info *info;
 	struct _send_data *data;
@@ -1112,7 +1123,7 @@ mail_receive_uri (const char *uri, int keep)
 	info->progress_bar = NULL;
 	info->status_label = NULL;
 	info->uri = g_strdup (uri);
-	info->keep = keep;
+	info->keep_on_server = keep_on_server;
 	info->cancel = camel_operation_new (operation_status, info);
 	info->cancel_button = NULL;
 	info->data = data;
@@ -1125,7 +1136,7 @@ mail_receive_uri (const char *uri, int keep)
 
 	switch (info->type) {
 	case SEND_RECEIVE:
-		mail_fetch_mail (info->uri, info->keep,
+		mail_fetch_mail (info->uri, info->keep_on_server,
 				 FILTER_SOURCE_INCOMING,
 				 info->cancel,
 				 receive_get_folder, info,
@@ -1184,7 +1195,7 @@ mail_send (void)
 	info->progress_bar = NULL;
 	info->status_label = NULL;
 	info->uri = g_strdup (transport->url);
-	info->keep = FALSE;
+	info->keep_on_server = FALSE;
 	info->cancel = NULL; 
 	info->cancel_button = NULL;
 	info->data = data;
