@@ -1,21 +1,22 @@
- /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
+/*
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
- *  Author: Johnny Jacob <jjohnny@novell.com>
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
  *
- *  This program is free software; you can redistribute it and/or
- *  modify it under the terms of version 2 of the GNU General Public
- *  License as published by the Free Software Foundation.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * Authors:
+ *		Johnny Jacob <jjohnny@novell.com>
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
@@ -23,6 +24,7 @@
 #include <glib/gi18n.h>
 #include <string.h>
 
+#include <glade/glade-xml.h>
 #include <gconf/gconf-client.h>
 
 #include <e-util/e-config.h>
@@ -42,9 +44,10 @@
 
 #include <mail/em-utils.h>
 
-#include "widgets/misc/e-attachment-bar.h"
 #include "composer/e-msg-composer.h"
 #include "composer/e-composer-actions.h"
+#include "widgets/misc/e-attachment-view.h"
+#include "widgets/misc/e-attachment-store.h"
 
 #define GCONF_KEY_ATTACH_REMINDER_CLUES "/apps/evolution/mail/attachment_reminder_clues"
 #define SIGNATURE "-- "
@@ -62,7 +65,7 @@ typedef struct {
 
 enum {
 	CLUE_KEYWORD_COLUMN,
-	CLUE_N_COLUMNS,
+	CLUE_N_COLUMNS
 };
 
 int e_plugin_lib_enable (EPluginLib *ep, int enable);
@@ -181,12 +184,13 @@ check_for_attachment_clues (gchar *msg)
 static gboolean
 check_for_attachment (EMsgComposer *composer)
 {
-	EAttachmentBar* bar = (EAttachmentBar*)e_msg_composer_get_attachment_bar (composer);
+	EAttachmentView *view;
+	EAttachmentStore *store;
 
-	if (e_attachment_bar_get_num_attachments (bar))
-		return TRUE;
+	view = e_msg_composer_get_attachment_view (composer);
+	store = e_attachment_view_get_store (view);
 
-	return FALSE;
+	return (e_attachment_store_get_num_attachments (store) > 0);
 }
 
 static gchar*
