@@ -78,7 +78,7 @@ ensure_google_source_group (void)
 		return;
 	}
 
-	manage_google_group (slist, FALSE);
+	e_source_list_ensure_group (slist, _("Google"), "google://", FALSE);
 	g_object_unref (slist);
 }
 
@@ -233,10 +233,10 @@ user_changed (GtkEntry *editable, ESource *source)
 }
 
 static char *
-get_refresh_minutes (GtkWidget *spin, GtkWidget *option)
+get_refresh_minutes (GtkWidget *spin, GtkWidget *combobox)
 {
 	int setting = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spin));
-	switch (gtk_option_menu_get_history (GTK_OPTION_MENU (option))) {
+	switch (gtk_combo_box_get_active (GTK_COMBO_BOX (combobox))) {
 	case 0:
 		/* minutes */
 		break;
@@ -264,30 +264,30 @@ static void
 spin_changed (GtkSpinButton *spin, ECalConfigTargetSource *t)
 {
 	gchar *refresh_str;
-	GtkWidget *option;
+	GtkWidget *combobox;
 
-	option = g_object_get_data (G_OBJECT(spin), "option");
+	combobox = g_object_get_data (G_OBJECT(spin), "combobox");
 
-	refresh_str = get_refresh_minutes ((GtkWidget *)spin, option);
+	refresh_str = get_refresh_minutes ((GtkWidget *)spin, combobox);
 	e_source_set_property (t->source, "refresh", refresh_str);
 	g_free (refresh_str);
 }
 
 static void
-option_changed (GtkSpinButton *option, ECalConfigTargetSource *t)
+combobox_changed (GtkComboBox *combobox, ECalConfigTargetSource *t)
 {
 	gchar *refresh_str;
 	GtkWidget *spin;
 
-	spin = g_object_get_data (G_OBJECT(option), "spin");
+	spin = g_object_get_data (G_OBJECT(combobox), "spin");
 
-	refresh_str = get_refresh_minutes (spin, (GtkWidget *)option);
+	refresh_str = get_refresh_minutes (spin, (GtkWidget *)combobox);
 	e_source_set_property (t->source, "refresh", refresh_str);
 	g_free (refresh_str);
 }
 
 static void
-set_refresh_time (ESource *source, GtkWidget *spin, GtkWidget *option)
+set_refresh_time (ESource *source, GtkWidget *spin, GtkWidget *combobox)
 {
 	int time;
 	int item_num = 0;
@@ -307,7 +307,7 @@ set_refresh_time (ESource *source, GtkWidget *spin, GtkWidget *option)
 		item_num = 1;
 		time /= 60;
 	}
-	gtk_option_menu_set_history (GTK_OPTION_MENU (option), item_num);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (combobox), item_num);
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (spin), time);
 }
 
@@ -391,6 +391,7 @@ claim_error (GtkWindow *parent, const char *error)
 			GTK_DIALOG_DESTROY_WITH_PARENT,
 			GTK_MESSAGE_ERROR,
 			GTK_BUTTONS_CLOSE,
+			"%s",
 			error);
 	gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
@@ -566,16 +567,13 @@ plugin_google  (EPlugin                    *epl,
 	GtkCellRenderer *renderer;
 	GtkListStore *store;
 
-	GtkWidget *option, *spin, *menu, *hbox;
-	GtkWidget *times [4];
-	int i;
+	GtkWidget *combobox, *spin, *hbox;
 
 	source = t->source;
 	group = e_source_peek_group (source);
 
 	widget = NULL;
-	if (!g_str_has_prefix (e_source_group_peek_base_uri (group),
-			       "Google")) {
+	if (g_ascii_strncasecmp ("google://", e_source_group_peek_base_uri (group), 9) != 0) {
 		return NULL;
 	}
 
@@ -647,28 +645,21 @@ plugin_google  (EPlugin                    *epl,
 	gtk_widget_show (spin);
 	gtk_box_pack_start (GTK_BOX(hbox), spin, FALSE, TRUE, 0);
 
-	option = gtk_option_menu_new ();
-	gtk_widget_show (option);
-	times[0] = gtk_menu_item_new_with_label (_("minutes"));
-	times[1] = gtk_menu_item_new_with_label (_("hours"));
-	times[2] = gtk_menu_item_new_with_label (_("days"));
-	times[3] = gtk_menu_item_new_with_label (_("weeks"));
+	if (!e_source_get_property (source, "refresh"))
+		e_source_set_property (source, "refresh", "30");
 
-	menu = gtk_menu_new ();
-	gtk_widget_show (menu);
-	for (i = 0; i < 4; i++) {
-		gtk_widget_show (times[i]);
-		gtk_menu_shell_append (GTK_MENU_SHELL (menu), times[i]);
-	}
-	gtk_option_menu_set_menu (GTK_OPTION_MENU (option), menu);
-	set_refresh_time (source, spin, option);
-	gtk_box_pack_start (GTK_BOX (hbox), option, FALSE, TRUE, 0);
+	combobox = gtk_combo_box_new_text ();
+	gtk_widget_show (combobox);
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), _("minutes"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), _("hours"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), _("days"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), _("weeks"));
+	set_refresh_time (source, spin, combobox);
+	gtk_box_pack_start (GTK_BOX (hbox), combobox, FALSE, TRUE, 0);
 
-	e_source_set_property (source, "refresh", "30");
-
-	g_object_set_data (G_OBJECT (option), "spin", spin);
-	g_signal_connect (G_OBJECT (option), "changed", G_CALLBACK (option_changed), t);
-	g_object_set_data (G_OBJECT (spin), "option", option);
+	g_object_set_data (G_OBJECT (combobox), "spin", spin);
+	g_signal_connect (G_OBJECT (combobox), "changed", G_CALLBACK (combobox_changed), t);
+	g_object_set_data (G_OBJECT (spin), "combobox", combobox);
 	g_signal_connect (G_OBJECT (spin), "value-changed", G_CALLBACK (spin_changed), t);
 
 	gtk_table_attach (GTK_TABLE (parent), hbox, 1, 2, row + 2, row + 3, GTK_EXPAND | GTK_FILL, 0, 0, 0);
