@@ -1,23 +1,23 @@
 /*
- * Authors:
- *  David Trowbridge <trowbrds@cs.colorado.edu>
- *  Gary Ekker <gekker@novell.com>
- *
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
- *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ *
+ *
+ * Authors:
+ *		David Trowbridge <trowbrds@cs.colorado.edu>
+ *		Gary Ekker <gekker@novell.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
@@ -120,7 +120,7 @@ e_publish_uri_from_xml (const gchar *xml)
 {
 	xmlDocPtr doc;
 	xmlNodePtr root, p;
-	xmlChar *location, *enabled, *frequency;
+	xmlChar *location, *enabled, *frequency, *fb_duration_value, *fb_duration_type;
 	xmlChar *publish_time, *format, *username = NULL;
 	GSList *events = NULL;
 	EPublishUri *uri;
@@ -146,6 +146,8 @@ e_publish_uri_from_xml (const gchar *xml)
 	frequency = xmlGetProp (root, (const unsigned char *)"frequency");
 	format = xmlGetProp (root, (const unsigned char *)"format");
 	publish_time = xmlGetProp (root, (const unsigned char *)"publish_time");
+	fb_duration_value = xmlGetProp (root, (xmlChar *)"fb_duration_value");
+	fb_duration_type = xmlGetProp (root, (xmlChar *)"fb_duration_type");
 
 	if (location != NULL)
 		uri->location = (char *)location;
@@ -158,6 +160,23 @@ e_publish_uri_from_xml (const gchar *xml)
 	if (publish_time != NULL)
 		uri->last_pub_time = (char *)publish_time;
 
+	if (fb_duration_value)
+		uri->fb_duration_value = atoi ((char *)fb_duration_value);
+	else
+		uri->fb_duration_value = -1;
+
+	if (uri->fb_duration_value < 1)
+		uri->fb_duration_value = 6;
+	else if (uri->fb_duration_value > 100)
+		uri->fb_duration_value = 100;
+
+	if (fb_duration_type && g_str_equal ((char *)fb_duration_type, "days"))
+		uri->fb_duration_type = FB_DURATION_DAYS;
+	else if (fb_duration_type && g_str_equal ((char *)fb_duration_type, "months"))
+		uri->fb_duration_type = FB_DURATION_MONTHS;
+	else
+		uri->fb_duration_type = FB_DURATION_WEEKS;
+
 	uri->password = g_strdup ("");
 
 	for (p = root->children; p != NULL; p = p->next) {
@@ -173,6 +192,8 @@ e_publish_uri_from_xml (const gchar *xml)
 	xmlFree (enabled);
 	xmlFree (frequency);
 	xmlFree (format);
+	xmlFree (fb_duration_value);
+	xmlFree (fb_duration_type);
 	xmlFreeDoc (doc);
 
 	return uri;
@@ -204,6 +225,17 @@ e_publish_uri_to_xml (EPublishUri *uri)
 	xmlSetProp (root, (const unsigned char *)"format", (unsigned char *)format);
 	xmlSetProp (root, (const unsigned char *)"publish_time", (unsigned char *)uri->last_pub_time);
 
+	g_free (format);
+	format = g_strdup_printf ("%d", uri->fb_duration_value);
+	xmlSetProp (root, (xmlChar *)"fb_duration_value", (xmlChar *)format);
+
+	if (uri->fb_duration_type == FB_DURATION_DAYS)
+		xmlSetProp (root, (xmlChar *)"fb_duration_type", (xmlChar *)"days");
+	else if (uri->fb_duration_type == FB_DURATION_MONTHS)
+		xmlSetProp (root, (xmlChar *)"fb_duration_type", (xmlChar *)"months");
+	else
+		xmlSetProp (root, (xmlChar *)"fb_duration_type", (xmlChar *)"weeks");
+
 	for (calendars = uri->events; calendars != NULL; calendars = g_slist_next (calendars)) {
 		xmlNodePtr node;
 		node = xmlNewChild (root, NULL, (const unsigned char *)"event", NULL);
