@@ -40,7 +40,7 @@ enum {
 	URL_LIST_ENABLED_COLUMN,
 	URL_LIST_LOCATION_COLUMN,
 	URL_LIST_URL_COLUMN,
-	URL_LIST_N_COLUMNS,
+	URL_LIST_N_COLUMNS
 };
 
 enum {
@@ -50,7 +50,7 @@ enum {
 	TYPE_SMB,
 	TYPE_DAV,
 	TYPE_DAVS,
-	TYPE_URI,
+	TYPE_URI
 };
 
 typedef struct _UrlEditorDialog UrlEditorDialog;
@@ -64,8 +64,11 @@ struct _UrlEditorDialog {
 
 	GladeXML *gui;
 
-	GtkWidget *publish_frequency;
 	GtkWidget *type_selector;
+	GtkWidget *fb_duration_label;
+	GtkWidget *fb_duration_spin;
+	GtkWidget *fb_duration_combo;
+	GtkWidget *publish_frequency;
 
 	GtkWidget *events_swin;
 
