@@ -1,23 +1,23 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
-/* e-shell-window.c
- *
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
- *
+/*
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ *
+ *
+ * Authors:
+ *		Ettore Perazzoli <ettore@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * Author: Ettore Perazzoli <ettore@ximian.com>
  */
 
 #ifdef HAVE_CONFIG_H
@@ -34,7 +34,6 @@
 
 #include "e-component-registry.h"
 #include "e-shell-window-commands.h"
-#include "e-shell-marshal.h"
 #include "e-sidebar.h"
 #include "es-menu.h"
 #include "es-event.h"
@@ -47,18 +46,13 @@
 #include <bonobo/bonobo-widget.h>
 
 #include <glib/gi18n.h>
-#include <libgnome/gnome-gconf.h>
 
 #include <gconf/gconf-client.h>
 
 #include <string.h>
 
-#ifdef NM_SUPPORT_GLIB
-gboolean e_shell_nm_glib_initialise (EShellWindow *window);
-void e_shell_nm_glib_dispose (EShellWindow *window);
-#elif NM_SUPPORT
-gboolean e_shell_dbus_initialise (EShellWindow *window);
-void e_shell_dbus_dispose (EShellWindow *window);
+#if NM_SUPPORT
+gboolean e_shell_dbus_initialise (EShell *shell);
 #endif
 
 /* A view for each component.  These are all created when EShellWindow is
@@ -477,19 +471,24 @@ sidebar_button_pressed_callback (ESidebar       *sidebar,
 static void
 offline_toggle_clicked_cb (EShellWindow *window)
 {
-	EShellWindowPrivate *priv = window->priv;
+	EShell *shell;
+	GNOME_Evolution_ShellState shell_state;
 
-	switch (e_shell_get_line_status (priv->shell.eshell)) {
+	shell = window->priv->shell.eshell;
+
+	switch (e_shell_get_line_status (shell)) {
 	case E_SHELL_LINE_STATUS_ONLINE:
-		e_shell_go_offline (priv->shell.eshell, window, GNOME_Evolution_USER_OFFLINE);
+		shell_state = GNOME_Evolution_USER_OFFLINE;
 		break;
 	case E_SHELL_LINE_STATUS_OFFLINE:
 	case E_SHELL_LINE_STATUS_FORCED_OFFLINE:
-		e_shell_go_online (priv->shell.eshell, window, GNOME_Evolution_USER_ONLINE);
+		shell_state = GNOME_Evolution_USER_ONLINE;
 		break;
 	default:
 		g_return_if_reached();
 	}
+
+	e_shell_set_line_status (shell, shell_state);
 }
 
 static void
@@ -573,11 +572,9 @@ setup_statusbar_notebook (EShellWindow *window)
 static void
 setup_nm_support (EShellWindow *window)
 {
-	#ifdef NM_SUPPORT_GLIB
-	       e_shell_nm_glib_initialise (window);
-	#elif NM_SUPPORT
-	       e_shell_dbus_initialise (window);
-	#endif
+#if NM_SUPPORT
+       e_shell_dbus_initialise (window->priv->shell.eshell);
+#endif
 }
 
 static void
@@ -795,7 +792,7 @@ setup_widgets (EShellWindow *window)
 			info->icon_name, width, 0);
 		g_string_append_printf(xml, "\" pixtype=\"filename\" pixname=\"%s\"/>"
 				       "</placeholder></submenu></submenu>\n",
-				       gtk_icon_info_get_filename (icon_info));
+				       icon_info ? gtk_icon_info_get_filename (icon_info) : "");
 		gtk_icon_info_free (icon_info);
 		bonobo_ui_component_set_translate (e_shell_window_peek_bonobo_ui_component (window),
 						   "/menu",
@@ -853,12 +850,6 @@ impl_dispose (GObject *object)
 		store_window_size (GTK_WIDGET (self));
 	}
 
-	#ifdef NM_SUPPORT_GLIB
-		e_shell_nm_glib_dispose (E_SHELL_WINDOW (object));
-	#elif NM_SUPPORT
-		e_shell_dbus_dispose (E_SHELL_WINDOW (object));
-	#endif
-
 	(* G_OBJECT_CLASS (e_shell_window_parent_class)->dispose) (object);
 }
 
@@ -922,7 +913,7 @@ store_window_size (GtkWidget* widget)
 	g_object_unref(client);
 
 	E_SHELL_WINDOW (widget)->priv->store_window_size_timer = 0;
-	return FALSE; // remove this timeout
+	return FALSE; /* remove this timeout */
 }
 
 static void
@@ -933,7 +924,7 @@ impl_size_alloc (GtkWidget* widget, GtkAllocation* alloc)
 
 	if (GTK_WIDGET_REALIZED(widget) && !(gdk_window_get_state(widget->window) & GDK_WINDOW_STATE_MAXIMIZED)) {
 		/* update the size storage timer */
-		self->priv->store_window_size_timer = g_timeout_add (1000, (GSourceFunc)store_window_size, self);
+		self->priv->store_window_size_timer = g_timeout_add_seconds (1, (GSourceFunc)store_window_size, self);
 	}
 
 	if (GTK_WIDGET_CLASS (e_shell_window_parent_class)->size_allocate) {
