@@ -1,23 +1,23 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
-/* e-combo-button.c
- *
- * Copyright (C) 2001  Ximian, Inc.
- *
+/*
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ *
+ *
+ * Authors:
+ *		Ettore Perazzoli <ettore@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * Author: Ettore Perazzoli <ettore@ximian.com>
  */
 
 #ifdef HAVE_CONFIG_H
@@ -26,7 +26,6 @@
 
 #include "e-combo-button.h"
 #include "ea-widgets.h"
-#include <e-util/e-icon-factory.h>
 
 struct _EComboButtonPrivate {
 	GdkPixbuf *icon;
@@ -461,7 +460,8 @@ e_combo_button_pack_hbox (EComboButton *combo_button)
 	gtk_container_add (GTK_CONTAINER (combo_button), priv->hbox);
 	gtk_widget_show (priv->hbox);
 
-	priv->icon_image = e_icon_factory_get_image (NULL, E_ICON_SIZE_MENU);
+	priv->icon_image = gtk_image_new_from_stock (
+		GTK_STOCK_MISSING_IMAGE, GTK_ICON_SIZE_MENU);
 	gtk_box_pack_start (GTK_BOX (priv->hbox), priv->icon_image, TRUE, TRUE, 0);
 	gtk_widget_show (priv->icon_image);
 
@@ -498,7 +498,8 @@ e_combo_button_pack_vbox (EComboButton *combo_button)
    	priv->vbox = gtk_vbox_new (FALSE, 0);
 	gtk_widget_show (priv->vbox);
 
-	priv->icon_image = e_icon_factory_get_image (NULL, E_ICON_SIZE_MENU);
+	priv->icon_image = gtk_image_new_from_stock (
+		GTK_STOCK_MISSING_IMAGE, GTK_ICON_SIZE_MENU);
 	gtk_box_pack_start (GTK_BOX (priv->vbox), priv->icon_image, TRUE, TRUE, 0);
 	gtk_widget_show (priv->icon_image);
 
@@ -572,7 +573,9 @@ e_combo_button_set_label (EComboButton *combo_button,
 	if (label == NULL)
 		label = "";
 
-	gtk_label_parse_uline (GTK_LABEL (priv->label), label);
+	gtk_label_set_label (GTK_LABEL (priv->label), label);
+	gtk_label_set_use_markup (GTK_LABEL (priv->label), FALSE);
+	gtk_label_set_use_underline (GTK_LABEL (priv->label), TRUE);
 }
 
 void
