@@ -49,7 +49,7 @@ static ESearchBarClass *parent_class = NULL;
 enum {
 	PROP_0,
 	PROP_QUERY,
-	PROP_STATE,
+	PROP_STATE
 };
 
 
@@ -325,12 +325,6 @@ option_changed (ESearchBar *esb, void *data)
 
 	d(printf("option changed, id = %d, setquery = %s %d\n", id, efb->setquery ? "true" : "false", esb->block_search));
 
-	if (esb->scopeitem_id == E_FILTERBAR_CURRENT_MESSAGE_ID) {
-		gtk_widget_set_sensitive (esb->option_button, FALSE);
-	} else {
-		gtk_widget_set_sensitive (esb->option_button, TRUE);
-	}
-
 	if (efb->setquery)
 		return;
 
@@ -383,8 +377,6 @@ build_items (ESearchBar *esb, ESearchBarItem *items, int type, int *start, GPtrA
 	GSList *gtksux = NULL;
 	int num;
 
-	/* So gtk calls a signal again if you connect to it WHILE inside a changed event.
-	   So this snot is to work around that shit fucked up situation */
 	for (i=0;i<rules->len;i++)
 		gtksux = g_slist_prepend(gtksux, rules->pdata[i]);
 
@@ -968,12 +960,28 @@ e_filter_bar_new (RuleContext *context,
 	EFilterBar *bar;
 
 	bar = g_object_new (e_filter_bar_get_type (), NULL);
+	((ESearchBar *)bar)->lite = FALSE;
 
  	e_filter_bar_new_construct (context, systemrules, userrules, config, data, bar);
 
 	return bar;
 }
 
+EFilterBar *
+e_filter_bar_lite_new (RuleContext *context,
+		  const char *systemrules,
+		  const char *userrules,
+		  EFilterBarConfigRule config,
+		  void *data)
+{
+	EFilterBar *bar;
+
+	bar = g_object_new (e_filter_bar_get_type (), NULL);
+	((ESearchBar *)bar)->lite = TRUE;
+ 	e_filter_bar_new_construct (context, systemrules, userrules, config, data, bar);
+
+	return bar;
+}
 
 void
 e_filter_bar_new_construct (RuleContext *context,
