@@ -1,22 +1,25 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* e-filter-bar.h
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
- * Author: Michael Zucchi <notzed@ximian.com>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+/*
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ *
+ *
+ * Authors:
+ *		Michael Zucchi <notzed@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * You should have received a copy of the GNU General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
  */
+
 #ifndef __E_FILTER_BAR_H__
 #define __E_FILTER_BAR_H__
 
@@ -92,10 +95,9 @@ enum {
 
 	/* preset option options */
 	E_FILTERBAR_ADVANCED_ID = -5,
-	E_FILTERBAR_CURRENT_MESSAGE_ID = -6,
 	E_FILTERBAR_CURRENT_FOLDER_ID = -7,
 	E_FILTERBAR_CURRENT_ACCOUNT_ID = -8,
-	E_FILTERBAR_ALL_ACCOUNTS_ID = -9,
+	E_FILTERBAR_ALL_ACCOUNTS_ID = -9
 };
 
 #define E_FILTERBAR_SAVE      { N_("_Save Search..."), E_FILTERBAR_SAVE_ID, 0 }
@@ -104,7 +106,6 @@ enum {
 #define E_FILTERBAR_ALL_ACCOUNTS { N_("All Accounts"), E_FILTERBAR_ALL_ACCOUNTS_ID, ESB_ITEMTYPE_RADIO }
 #define E_FILTERBAR_CURRENT_ACCOUNT { N_("Current Account"), E_FILTERBAR_CURRENT_ACCOUNT_ID, ESB_ITEMTYPE_RADIO }
 #define E_FILTERBAR_CURRENT_FOLDER { N_("Current Folder"), E_FILTERBAR_CURRENT_FOLDER_ID, ESB_ITEMTYPE_RADIO }
-#define E_FILTERBAR_CURRENT_MESSAGE { N_("Current Message"), E_FILTERBAR_CURRENT_MESSAGE_ID, ESB_ITEMTYPE_RADIO }
 #define E_FILTERBAR_SEPARATOR { NULL, 0, 0 }
 
 #ifdef JUST_FOR_TRANSLATORS
@@ -123,6 +124,12 @@ EFilterBar *e_filter_bar_new      (RuleContext *context,
 				   const char *userrules,
 				   EFilterBarConfigRule config,
 				   void *data);
+EFilterBar *e_filter_bar_lite_new (RuleContext *context,
+				   const char *systemrules,
+				   const char *userrules,
+				   EFilterBarConfigRule config,
+				   void *data);
+
 void
 e_filter_bar_new_construct 	  (RuleContext *context,
 				   const char *systemrules,
