@@ -1,4 +1,4 @@
-/* 
+/*
  * Copyright © 2000 Eazel, Inc.
  * Copyright © 2002-2004 Marco Pesenti Gritti
  * Copyright © 2004, 2006 Christian Persch
@@ -20,26 +20,47 @@
  * Author: Andy Hertzfeld <andy@eazel.com>
  *
  * Ephy port by Marco Pesenti Gritti <marco@it.gnome.org>
- * 
+ *
  * $Id: e-spinner.c 12639 2006-12-12 17:06:55Z chpe $
  */
 
 /*
  * From Nautilus ephy-spinner.c
- */ 
+ */
 
 #include "config.h"
 
 #include "e-spinner.h"
 
+#define E_TYPE_SPINNER		(e_spinner_get_type ())
+#define E_SPINNER(o)			(G_TYPE_CHECK_INSTANCE_CAST ((o), E_TYPE_SPINNER, ESpinner))
+#define E_SPINNER_CLASS(k)		(G_TYPE_CHECK_CLASS_CAST((k), E_TYPE_SPINNER, ESpinnerClass))
+#define E_IS_SPINNER(o)		(G_TYPE_CHECK_INSTANCE_TYPE ((o), E_TYPE_SPINNER))
+#define E_IS_SPINNER_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), E_TYPE_SPINNER))
+#define E_SPINNER_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), E_TYPE_SPINNER, ESpinnerClass))
+
+typedef struct _ESpinner		ESpinner;
+typedef struct _ESpinnerClass	ESpinnerClass;
+typedef struct _ESpinnerDetails	ESpinnerDetails;
+
+struct _ESpinner
+{
+	GtkWidget parent;
+
+	/*< private >*/
+	ESpinnerDetails *details;
+};
+
+struct _ESpinnerClass
+{
+	GtkWidgetClass parent_class;
+};
+
 #define LOG(msg, args...)
 #define START_PROFILER(name)
 #define STOP_PROFILER(name)
 
-#include <gdk-pixbuf/gdk-pixbuf.h>
-#include <gtk/gtkicontheme.h>
-#include <gtk/gtkiconfactory.h>
-#include <gtk/gtksettings.h>
+#include "e-util/e-icon-factory.h"
 
 /* Spinner cache implementation */
 
@@ -101,6 +122,7 @@ static void e_spinner_cache_class_init (ESpinnerCacheClass *klass);
 static void e_spinner_cache_init	  (ESpinnerCache *cache);
 
 static GObjectClass *e_spinner_cache_parent_class;
+static gpointer spinner_cache = NULL;
 
 static GType
 e_spinner_cache_get_type (void)
@@ -221,8 +243,7 @@ scale_to_size (GdkPixbuf *pixbuf,
 
 	if (pw != dw || ph != dh)
 	{
-		result = gdk_pixbuf_scale_simple (pixbuf, dw, dh,
-						  GDK_INTERP_BILINEAR);
+		result = e_icon_factory_pixbuf_scale (pixbuf, dw, dh);
 		g_object_unref (pixbuf);
 		return result;
 	}
@@ -258,7 +279,7 @@ e_spinner_images_load (GdkScreen *screen,
 	if (icon_info == NULL)
 	{
 		g_warning ("Throbber animation not found");
-	
+
 		/* If the icon naming spec compliant name wasn't found, try the old name */
 		icon_info = gtk_icon_theme_lookup_icon (icon_theme,
 							SPINNER_FALLBACK_ICON_NAME,
@@ -462,7 +483,7 @@ e_spinner_cache_init (ESpinnerCache *cache)
 static void
 e_spinner_cache_finalize (GObject *object)
 {
-	ESpinnerCache *cache = E_SPINNER_CACHE (object); 
+	ESpinnerCache *cache = E_SPINNER_CACHE (object);
 	ESpinnerCachePrivate *priv = cache->priv;
 
 	g_hash_table_destroy (priv->hash);
@@ -484,24 +505,17 @@ e_spinner_cache_class_init (ESpinnerCacheClass *klass)
 	g_type_class_add_private (object_class, sizeof (ESpinnerCachePrivate));
 }
 
-static ESpinnerCache *spinner_cache = NULL;
-
 static ESpinnerCache *
 e_spinner_cache_ref (void)
 {
-	if (spinner_cache == NULL)
+	if (G_UNLIKELY (spinner_cache == NULL))
 	{
-		ESpinnerCache **cache_ptr;
-
 		spinner_cache = g_object_new (E_TYPE_SPINNER_CACHE, NULL);
-		cache_ptr = &spinner_cache;
-		g_object_add_weak_pointer (G_OBJECT (spinner_cache),
-					   (gpointer *) cache_ptr);
-
-		return spinner_cache;
+		g_object_add_weak_pointer (
+                        G_OBJECT (spinner_cache), &spinner_cache);
 	}
-		
-	return g_object_ref (spinner_cache);
+
+	return g_object_ref_sink (spinner_cache);
 }
 
 /* Spinner implementation */
@@ -528,7 +542,7 @@ static void e_spinner_init	    (ESpinner *spinner);
 
 static GObjectClass *parent_class;
 
-GType
+static GType
 e_spinner_get_type (void)
 {
 	static GType type = 0;
@@ -650,7 +664,7 @@ e_spinner_expose (GtkWidget *widget,
 
 	/* Otherwise |images| will be NULL anyway */
 	g_return_val_if_fail (images->n_animation_pixbufs > 0, FALSE);
-		
+
 	g_return_val_if_fail (details->current_image >= 0 &&
 		  details->current_image < images->n_animation_pixbufs, FALSE);
 
@@ -711,13 +725,7 @@ bump_spinner_frame_cb (ESpinner *spinner)
 	return TRUE;
 }
 
-/**
- * e_spinner_start:
- * @spinner: a #ESpinner
- *
- * Start the spinner animation.
- **/
-void
+static void
 e_spinner_start (ESpinner *spinner)
 {
 	ESpinnerDetails *details = spinner->details;
@@ -752,39 +760,7 @@ e_spinner_remove_update_callback (ESpinner *spinner)
 	}
 }
 
-/**
- * e_spinner_stop:
- * @spinner: a #ESpinner
- *
- * Stop the spinner animation.
- **/
-void
-e_spinner_stop (ESpinner *spinner)
-{
-	ESpinnerDetails *details = spinner->details;
-
-	details->spinning = FALSE;
-	details->current_image = 0;
-
-	if (details->timer_task != 0)
-	{
-		e_spinner_remove_update_callback (spinner);
-
-		if (GTK_WIDGET_MAPPED (GTK_WIDGET (spinner)))
-		{
-			gtk_widget_queue_draw (GTK_WIDGET (spinner));
-		}
-	}
-}
-
-/*
- * e_spinner_set_size:
- * @spinner: a #ESpinner
- * @size: the size of type %GtkIconSize
- *
- * Set the size of the spinner.
- **/
-void
+static void
 e_spinner_set_size (ESpinner *spinner,
 		       GtkIconSize size)
 {
@@ -804,6 +780,27 @@ e_spinner_set_size (ESpinner *spinner,
 }
 
 #if 0
+
+static void
+e_spinner_stop (ESpinner *spinner)
+{
+	ESpinnerDetails *details = spinner->details;
+
+	details->spinning = FALSE;
+	details->current_image = 0;
+
+	if (details->timer_task != 0)
+	{
+		e_spinner_remove_update_callback (spinner);
+
+		if (GTK_WIDGET_MAPPED (GTK_WIDGET (spinner)))
+		{
+			gtk_widget_queue_draw (GTK_WIDGET (spinner));
+		}
+	}
+}
+
+
 /*
  * e_spinner_set_timeout:
  * @spinner: a #ESpinner
@@ -891,9 +888,10 @@ e_spinner_dispose (GObject *object)
 {
 	ESpinner *spinner = E_SPINNER (object);
 
-	g_signal_handlers_disconnect_by_func
-			(spinner->details->icon_theme,
-		 G_CALLBACK (icon_theme_changed_cb), spinner);
+	if (spinner->details->icon_theme)
+		g_signal_handlers_disconnect_by_func
+				(spinner->details->icon_theme,
+			 G_CALLBACK (icon_theme_changed_cb), spinner);
 
 	G_OBJECT_CLASS (parent_class)->dispose (object);
 }
@@ -968,17 +966,14 @@ e_spinner_class_init (ESpinnerClass *class)
 	g_type_class_add_private (object_class, sizeof (ESpinnerDetails));
 }
 
-/*
- * e_spinner_new:
- *
- * Create a new #ESpinner. The spinner is a widget
- * that gives the user feedback about network status with
- * an animated image.
- *
- * Return Value: the spinner #GtkWidget
- **/
-GtkWidget *
-e_spinner_new (void)
+GtkWidget *e_spinner_new_spinning_small_shown (void)
 {
-	return GTK_WIDGET (g_object_new (E_TYPE_SPINNER, NULL));
+  ESpinner *image;
+  image = E_SPINNER (g_object_new (E_TYPE_SPINNER, NULL));
+
+  e_spinner_set_size (image, GTK_ICON_SIZE_SMALL_TOOLBAR);
+  e_spinner_start (image);
+  gtk_widget_show (GTK_WIDGET(image));
+
+  return GTK_WIDGET (image);
 }
