@@ -1,29 +1,28 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
-/* test-multi-config-dialog.c
- *
- * Copyright (C) 2002 Ximian, Inc.
- *
+/*
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
  *
  * Authors:
- *   Ettore Perazzoli <ettore@ximian.com>
+ *		Ettore Perazzoli <ettore@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ *
  */
 
 #include "e-multi-config-dialog.c"
 
-#include <gnome.h>
+#include <gtk/gtk.h>
 
 
 #define NUM_PAGES 10
@@ -76,15 +75,13 @@ main (int argc, char **argv)
 {
 	GtkWidget *dialog;
 
-	gnome_program_init (
-		"test-multi-config-dialog", "0.0", LIBGNOMEUI_MODULE,
-		argc, argv, GNOME_PARAM_NONE);
+	gtk_init (&argc, &argv);
 
 	dialog = e_multi_config_dialog_new ();
 
-	gtk_window_set_default_size (GTK_WINDOW (dialog), 400, 300);
-	g_signal_connect((dialog), "delete_event",
-			    G_CALLBACK (delete_event_callback), NULL);
+	g_signal_connect(
+		dialog, "delete-event",
+		G_CALLBACK (delete_event_callback), NULL);
 
 	add_pages (E_MULTI_CONFIG_DIALOG (dialog));
 
