@@ -1,24 +1,23 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * e-table-group.c
- * Copyright 2000, 2001, Ximian, Inc.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ *
  *
  * Authors:
- *   Chris Lahey <clahey@ximian.com>
+ *		Chris Lahey <clahey@ximian.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License, version 2, as published by the Free Software Foundation.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
  */
 
 #include <config.h>
@@ -156,7 +155,7 @@ e_table_group_add (ETableGroup *etg,
 	g_return_if_fail (etg != NULL);
 	g_return_if_fail (E_IS_TABLE_GROUP (etg));
 
-	g_assert (ETG_CLASS (etg)->add != NULL);
+	g_return_if_fail (ETG_CLASS (etg)->add != NULL);
 	ETG_CLASS (etg)->add (etg, row);
 }
 
@@ -177,7 +176,7 @@ e_table_group_add_array (ETableGroup *etg,
 	g_return_if_fail (etg != NULL);
 	g_return_if_fail (E_IS_TABLE_GROUP (etg));
 
-	g_assert (ETG_CLASS (etg)->add_array != NULL);
+	g_return_if_fail (ETG_CLASS (etg)->add_array != NULL);
 	ETG_CLASS (etg)->add_array (etg, array, count);
 }
 
@@ -194,7 +193,7 @@ e_table_group_add_all (ETableGroup *etg)
 	g_return_if_fail (etg != NULL);
 	g_return_if_fail (E_IS_TABLE_GROUP (etg));
 
-	g_assert (ETG_CLASS (etg)->add_all != NULL);
+	g_return_if_fail (ETG_CLASS (etg)->add_all != NULL);
 	ETG_CLASS (etg)->add_all (etg);
 }
 
@@ -216,7 +215,7 @@ e_table_group_remove (ETableGroup *etg,
 	g_return_val_if_fail (etg != NULL, FALSE);
 	g_return_val_if_fail (E_IS_TABLE_GROUP (etg), FALSE);
 
-	g_assert (ETG_CLASS (etg)->remove != NULL);
+	g_return_val_if_fail (ETG_CLASS (etg)->remove != NULL, FALSE);
 	return ETG_CLASS (etg)->remove (etg, row);
 }
 
@@ -238,7 +237,7 @@ e_table_group_increment (ETableGroup *etg,
 	g_return_if_fail (etg != NULL);
 	g_return_if_fail (E_IS_TABLE_GROUP (etg));
 
-	g_assert (ETG_CLASS (etg)->increment != NULL);
+	g_return_if_fail (ETG_CLASS (etg)->increment != NULL);
 	ETG_CLASS (etg)->increment (etg, position, amount);
 }
 
@@ -260,7 +259,7 @@ e_table_group_decrement (ETableGroup *etg,
 	g_return_if_fail (etg != NULL);
 	g_return_if_fail (E_IS_TABLE_GROUP (etg));
 
-	g_assert (ETG_CLASS (etg)->decrement != NULL);
+	g_return_if_fail (ETG_CLASS (etg)->decrement != NULL);
 	ETG_CLASS (etg)->decrement (etg, position, amount);
 }
 
@@ -278,7 +277,7 @@ e_table_group_row_count (ETableGroup *etg)
 	g_return_val_if_fail (etg != NULL, 0);
 	g_return_val_if_fail (E_IS_TABLE_GROUP (etg), -1);
 
-	g_assert (ETG_CLASS (etg)->row_count != NULL);
+	g_return_val_if_fail (ETG_CLASS (etg)->row_count != NULL, -1);
 	return ETG_CLASS (etg)->row_count (etg);
 }
 
@@ -299,7 +298,7 @@ e_table_group_set_focus (ETableGroup *etg,
 	g_return_if_fail (etg != NULL);
 	g_return_if_fail (E_IS_TABLE_GROUP (etg));
 
-	g_assert (ETG_CLASS (etg)->set_focus != NULL);
+	g_return_if_fail (ETG_CLASS (etg)->set_focus != NULL);
 	ETG_CLASS (etg)->set_focus (etg, direction, view_col);
 }
 
@@ -317,7 +316,7 @@ e_table_group_get_focus (ETableGroup *etg)
 	g_return_val_if_fail (etg != NULL, FALSE);
 	g_return_val_if_fail (E_IS_TABLE_GROUP (etg), FALSE);
 
-	g_assert (ETG_CLASS (etg)->get_focus != NULL);
+	g_return_val_if_fail (ETG_CLASS (etg)->get_focus != NULL, FALSE);
 	return ETG_CLASS (etg)->get_focus (etg);
 }
 
@@ -332,10 +331,10 @@ e_table_group_get_focus (ETableGroup *etg)
 gint
 e_table_group_get_focus_column (ETableGroup *etg)
 {
-	g_return_val_if_fail (etg != NULL, FALSE);
+	g_return_val_if_fail (etg != NULL, -1);
 	g_return_val_if_fail (E_IS_TABLE_GROUP (etg), -1);
 
-	g_assert (ETG_CLASS (etg)->get_focus_column != NULL);
+	g_return_val_if_fail (ETG_CLASS (etg)->get_focus_column != NULL, -1);
 	return ETG_CLASS (etg)->get_focus_column (etg);
 }
 
@@ -354,7 +353,7 @@ e_table_group_get_printable (ETableGroup *etg)
 	g_return_val_if_fail (etg != NULL, NULL);
 	g_return_val_if_fail (E_IS_TABLE_GROUP (etg), NULL);
 
-	g_assert (ETG_CLASS (etg)->get_printable != NULL);
+	g_return_val_if_fail (ETG_CLASS (etg)->get_printable != NULL, NULL);
 	return ETG_CLASS (etg)->get_printable (etg);
 }
 
@@ -378,10 +377,20 @@ e_table_group_compute_location (ETableGroup *etg, int *x, int *y, int *row, int
 	g_return_if_fail (etg != NULL);
 	g_return_if_fail (E_IS_TABLE_GROUP (etg));
 
-	g_assert (ETG_CLASS (etg)->compute_location != NULL);
+	g_return_if_fail (ETG_CLASS (etg)->compute_location != NULL);
 	ETG_CLASS (etg)->compute_location (etg, x, y, row, col);
 }
 
+void
+e_table_group_get_mouse_over (ETableGroup *etg, int *row, int *col)
+{
+	g_return_if_fail (etg != NULL);
+	g_return_if_fail (E_IS_TABLE_GROUP (etg));
+
+	g_return_if_fail (ETG_CLASS (etg)->get_mouse_over != NULL);
+	ETG_CLASS (etg)->get_mouse_over (etg, row, col);
+}
+
 /**
  * e_table_group_get_position
  * @eti: %ETableGroup to look in.
@@ -408,7 +417,7 @@ e_table_group_get_cell_geometry  (ETableGroup *etg,
 	g_return_if_fail (etg != NULL);
 	g_return_if_fail (E_IS_TABLE_GROUP (etg));
 
-	g_assert (ETG_CLASS (etg)->get_cell_geometry != NULL);
+	g_return_if_fail (ETG_CLASS (etg)->get_cell_geometry != NULL);
 	ETG_CLASS (etg)->get_cell_geometry (etg, row, col, x, y, width, height);
 }
 
@@ -639,6 +648,7 @@ etg_class_init (ETableGroupClass *klass)
 	klass->get_focus = etg_get_focus;
 	klass->get_printable = NULL;
 	klass->compute_location = NULL;
+	klass->get_mouse_over = NULL;
 	klass->get_cell_geometry = NULL;
 
 	etg_signals [CURSOR_CHANGE] =
@@ -647,7 +657,7 @@ etg_class_init (ETableGroupClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (ETableGroupClass, cursor_change),
 			      NULL, NULL,
-			      e_util_marshal_NONE__INT,
+			      g_cclosure_marshal_VOID__INT,
 			      G_TYPE_NONE, 1, G_TYPE_INT);
 
 	etg_signals [CURSOR_ACTIVATED] =
@@ -656,7 +666,7 @@ etg_class_init (ETableGroupClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (ETableGroupClass, cursor_activated),
 			      NULL, NULL,
-			      e_util_marshal_NONE__INT,
+			      g_cclosure_marshal_VOID__INT,
 			      G_TYPE_NONE, 1, G_TYPE_INT);
 
 	etg_signals [DOUBLE_CLICK] =
@@ -665,7 +675,7 @@ etg_class_init (ETableGroupClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (ETableGroupClass, double_click),
 			      NULL, NULL,
-			      e_util_marshal_NONE__INT_INT_BOXED,
+			      e_marshal_NONE__INT_INT_BOXED,
 			      G_TYPE_NONE, 3, G_TYPE_INT,
 			      G_TYPE_INT, GDK_TYPE_EVENT);
 
@@ -675,7 +685,7 @@ etg_class_init (ETableGroupClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (ETableGroupClass, right_click),
 			      NULL, NULL,
-			      e_util_marshal_INT__INT_INT_BOXED,
+			      e_marshal_INT__INT_INT_BOXED,
 			      G_TYPE_INT, 3, G_TYPE_INT, G_TYPE_INT, GDK_TYPE_EVENT);
 
 	etg_signals [CLICK] =
@@ -684,7 +694,7 @@ etg_class_init (ETableGroupClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (ETableGroupClass, click),
 			      NULL, NULL,
-			      e_util_marshal_INT__INT_INT_BOXED,
+			      e_marshal_INT__INT_INT_BOXED,
 			      G_TYPE_INT, 3, G_TYPE_INT,
 			      G_TYPE_INT, GDK_TYPE_EVENT);
 
@@ -694,7 +704,7 @@ etg_class_init (ETableGroupClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (ETableGroupClass, key_press),
 			      NULL, NULL,
-			      e_util_marshal_INT__INT_INT_BOXED,
+			      e_marshal_INT__INT_INT_BOXED,
 			      G_TYPE_INT, 3, G_TYPE_INT,
 			      G_TYPE_INT, GDK_TYPE_EVENT);
 
@@ -704,7 +714,7 @@ etg_class_init (ETableGroupClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (ETableGroupClass, start_drag),
 			      NULL, NULL,
-			      e_util_marshal_INT__INT_INT_BOXED,
+			      e_marshal_INT__INT_INT_BOXED,
 			      G_TYPE_INT, 3, G_TYPE_INT,
 			      G_TYPE_INT, GDK_TYPE_EVENT);
 }
