@@ -656,7 +656,7 @@ e_table_setup_header (ETable *e_table)
 
 	gtk_widget_show (GTK_WIDGET (e_table->header_canvas));
 
-	pointer = g_strdup_printf("%p", e_table);
+	pointer = g_strdup_printf("%p", (gpointer) e_table);
 
 	e_table->header_item = gnome_canvas_item_new (
 		gnome_canvas_root (e_table->header_canvas),
